@@ -139,15 +139,17 @@ class Set(WMLResource):
                 project_endpoint = self._href_definitions.get_project_href(project_id)
                 project_details = requests.get(project_endpoint, headers=self._client._get_headers(), verify=False)
                 if project_details.status_code != 200 and project_details.status_code != 204:
-                    print("Failed to set Project.")
-                    # print(project_details.text)
-                    print('Project with id ' + project_id + " does not exist.")
+                    print("Failed to set Project: " + project_details.text)
                     self._client.default_project_id = None
                     return "FAILURE"
                 else:
                     if self._client.CLOUD_PLATFORM_SPACES:
+                        instance_id = "not_found"
                         if 'compute' in project_details.json()['entity'].keys():
-                            instance_id = project_details.json()['entity']['compute'][0]['guid']
+                            for comp_obj in project_details.json()['entity']['compute']:
+                                if comp_obj['type'] == 'machine_learning':
+                                    instance_id = comp_obj['guid']
+                                    break
                             self._client.wml_credentials[u'instance_id'] = instance_id
                             self._client.service_instance = ServiceInstanceNewPlan(self._client)
                             self._client.service_instance.details = self._client.service_instance.get_details()
