@@ -43,9 +43,14 @@ from ibm_watson_machine_learning.instance_new_plan import ServiceInstanceNewPlan
 from ibm_watson_machine_learning.migration_v4ga_cloud import Migrationv4GACloud
 from ibm_watson_machine_learning.remote_training_system import RemoteTrainingSystem
 
+from ibm_watson_machine_learning.export_assets import Export
+from ibm_watson_machine_learning.import_assets import Import
+from ibm_watson_machine_learning.volumes import Volume
+
 import copy
 import os
 import requests
+import sys
 
 
 '''
@@ -280,7 +285,19 @@ class APIClient:
         if self.CLOUD_PLATFORM_SPACES or self.ICP_PLATFORM_SPACES:
             # For cloud, service_instance.details will be set during space creation( if instance is associated ) or
             # while patching a space with an instance
+            import sys
+            if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
+                if self.CLOUD_PLATFORM_SPACES:
+                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021."
+                          "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create new assets using this client."
+                          "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
+                elif self.ICP_PLATFORM_SPACES:
+                    print("DEPRECATED!! The Python 3.6 framework is deprecated and will be removed from a future release. "
+                    "We recommend you migrate your assets and use a Python 3.7 framework instead."
+                    "For details, see https://www.ibm.com/support/knowledgecenter/SSQNUZ_current/wsj/analyze-data/pm_service_supported_frameworks.html")
+
             self.service_instance = ServiceInstanceNewPlan(self)
+            self.volumes = Volume(self)
 
             if self.ICP_PLATFORM_SPACES:
                 self.service_instance.details = self.service_instance.get_details()
@@ -289,6 +306,9 @@ class APIClient:
 
             self.spaces = PlatformSpaces(self)
 
+            self.export_assets = Export(self)
+            self.import_assets = Import(self)
+
             if self.ICP_PLATFORM_SPACES:
                 self.shiny = Shiny(self)
 
@@ -358,20 +378,20 @@ class APIClient:
             if self.default_space_id is None:
                 raise WMLClientError("It is mandatory to set the space. Use client.set.default_space(<SPACE_UID>) to proceed.")
 
-    def _params(self, skip_space_project_chk=False):
+    def _params(self, skip_space_project_chk=False, skip_for_create=False):
         params = {}
         if self.CAMS or self.CLOUD_PLATFORM_SPACES:
             if self.CLOUD_PLATFORM_SPACES or self.ICP_PLATFORM_SPACES:
                 params.update({'version': self.version_param})
-
-            if self.default_space_id is not None:
-                params.update({'space_id': self.default_space_id})
-            elif self.default_project_id is not None:
-                params.update({'project_id': self.default_project_id})
-            else:
-                # For system software/hardware specs
-                if skip_space_project_chk is False:
-                    raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
+            if not skip_for_create:
+                if self.default_space_id is not None:
+                    params.update({'space_id': self.default_space_id})
+                elif self.default_project_id is not None:
+                    params.update({'project_id': self.default_project_id})
+                else:
+                    # For system software/hardware specs
+                    if skip_space_project_chk is False:
+                        raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
         if self.WSD:
             if self.default_project_id is not None:
@@ -381,7 +401,7 @@ class APIClient:
                     "It is mandatory to set the project id. Use client.set.default_project(<PROJECT_UID>) to proceed.")
         return params
 
-    def _get_headers(self, content_type='application/json', no_content_type=False, wsdconnection_api_req=False):
+    def _get_headers(self, content_type='application/json', no_content_type=False, wsdconnection_api_req=False, zen=False):
         if self.WSD:
                 headers = {'X-WML-User-Client': 'PythonClient'}
                 if self.project_id is not None:
@@ -394,6 +414,9 @@ class APIClient:
                     token = "desktop-token"
                 headers.update({'Authorization':  "Bearer " + token})
 
+        elif zen:
+            headers= {'Content-Type': content_type}
+            headers.update({'Authorization': "Bearer " + self.service_instance._create_token()})
         else:
             if self.proceed is True:
                 token = "Bearer "+ self.wml_credentials["token"]
