@@ -19,6 +19,7 @@ from ibm_watson_machine_learning.metanames import ConnectionMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
 import os
+import json
 
 _DEFAULT_LIST_LENGTH = 0
 
@@ -148,7 +149,65 @@ class Connections(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, meta_props):
         """
-                Creates a connection.
+                Creates a connection. Input to PROPERTIES field examples
+
+                1. MySQL
+                      client.connections.ConfigurationMetaNames.PROPERTIES: {
+                        "database": "database",
+                        "password": "password",
+                        "port": "3306",
+                        "host": "host url",
+                        "ssl": "false",
+                        "username": "username"
+                      }
+
+                2. Google Big query
+
+                   a. Method1: Use service account json. The service account json generated can be provided as
+                               input as-is. Provide actual values in json. Example is only indicative to show
+                               the fields. Refer to Google big query documents how to generate the service account json
+
+                      client.connections.ConfigurationMetaNames.PROPERTIES: {
+                          "type": "service_account",
+                          "project_id": "project_id",
+                          "private_key_id": "private_key_id",
+                          "private_key": "private key contents"
+                          "client_email": "client_email",
+                          "client_id": "client_id",
+                          "auth_uri": "https://accounts.google.com/o/oauth2/auth",
+                          "token_uri": "https://oauth2.googleapis.com/token",
+                          "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
+                          "client_x509_cert_url": "client_x509_cert_url"
+                      }
+
+                    b. Method2: Using OAuth Method. Refer to Google big query documents how to generate OAuth token
+
+                       client.connections.ConfigurationMetaNames.PROPERTIES: {
+                          "access_token": "access token generated for big query"
+                          "refresh_token": "refresh token"
+                          "project_id": "project_id",
+                          "client_secret": "This is your gmail account password",
+                          "client_id": "client_id"
+                      }
+
+                3. MS SQL
+                     client.connections.ConfigurationMetaNames.PROPERTIES: {
+                          "database": "database",
+                          "password": "password",
+                          "port": "1433",
+                          "host": "host",
+                          "username": "username"
+                     }
+
+                4. Tera data
+                     client.connections.ConfigurationMetaNames.PROPERTIES: {
+                          "database": "database",
+                          "password": "password",
+                          "port": "1433",
+                          "host": "host",
+                          "username": "username"
+                     }
+
 
                 **Parameters**
 
@@ -165,11 +224,16 @@ class Connections(WMLResource):
                     **return type**: dict\n
 
                 **Example**
+                     >>> sqlserver_data_source_type_id = client.connections.get_datasource_type_uid_by_name('sqlserver')
                      >>> connections_details = client.connections.create({
-                     >>> client.connections.ConnectionsMetaNames.NAME: "dashdb connection",
-                     >>> client.connections.ConnectionsMetaNames.DESCRIPTION: "connection description",
-                     >>> client.connections.ConnectionsMetaNames.DATASOURCE_TYPE: "",
-                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: ""
+                     >>> client.connections.ConfigurationMetaNames.NAME: "sqlserver connection",
+                     >>> client.connections.ConfigurationMetaNames.DESCRIPTION: "connection description",
+                     >>> client.connections.ConfigurationMetaNames.DATASOURCE_TYPE: sqlserver_data_source_type_id,
+                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: { "database": "database",
+                     >>>                                                         "password": "password",
+                     >>>                                                         "port": "1433",
+                     >>>                                                         "host": "host",
+                     >>>                                                         "username": "username"}
                      >>> })
 
         """
@@ -179,6 +243,17 @@ class Connections(WMLResource):
             with_validation=True,
             client=self._client
         )
+
+        big_query_data_source_type_id = self.get_datasource_type_uid_by_name('bigquery')
+
+        # Either service acct json credentials can be given or oauth json can be given
+        # If service acct json, then we need to create a newline json with "credentials" key
+        if connection_meta[u'datasource_type'] == big_query_data_source_type_id:
+            if 'private_key' in connection_meta[u'properties']:
+                result = json.dumps(connection_meta[u'properties'], separators=(',\n', ':'))
+                newmap = {"credentials": result}
+                connection_meta[u'properties'] = newmap
+
         connection_meta.update({'origin_country': 'US'})
         #Step1  : Create an asset
         print("Creating connections...")
