@@ -221,7 +221,7 @@ class Batch(BaseDeployment):
                     raise NoneDataConnection('payload')
                 payload = [new_conn for conn in payload for new_conn in conn._subdivide_connection()]
                 payload = validate_source_data_connections(source_data_connections=payload,
-                                                           workspace=self._source_workspace,
+                                                           workspace=self._target_workspace,
                                                            deployment=True)
                 payload = [data_connection._to_dict() for data_connection in payload]
             elif isinstance(payload[0], dict):
@@ -320,10 +320,14 @@ class Batch(BaseDeployment):
         """
         scoring_params = self.get_job_params(scoring_job_id)['entity']['scoring']
         input_data_references = self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA_REFERENCES
+        output_data_reference = self._target_workspace.wml_client.deployments.ScoringMetaNames.OUTPUT_DATA_REFERENCE
 
         if input_data_references in scoring_params:
             payload_ref = [input_ref for input_ref in scoring_params[input_data_references]]
 
+            if 'href' in scoring_params[output_data_reference]['location']:
+                del scoring_params[output_data_reference]['location']['href']
+
             return self.run_job(payload=payload_ref, output_data_reference=scoring_params['output_data_reference'],
                                 background_mode=background_mode)
         else:
@@ -483,10 +487,12 @@ class Batch(BaseDeployment):
         else:
             return data_connection
 
+    @BaseDeployment._project_to_space_to_project
     def get_job_id(self, batch_scoring_details):
         """Get id from batch scoring details."""
         return self._target_workspace.wml_client.deployments.get_job_uid(batch_scoring_details)
 
+    @BaseDeployment._project_to_space_to_project
     def list_jobs(self):
         """Returns pandas DataFrame with list of deployment jobs"""
 
