@@ -239,6 +239,8 @@ class Deployments(WMLResource):
                         time.sleep(5)
                         deployment_details = self._client.deployments.get_details(deployment_uid)
                         #this is wrong , needs to update for ICP
+                        if "system" in deployment_details:
+                            print("Note: " + deployment_details['system']['warnings'][0]['message'])
                         if self._ICP and not self._client.ICP_PLATFORM_SPACES:
                             scoringUrl = deployment_details.get(u'entity').get(u'asset').get('href').replace('https://wml-os-envoy:16600', predictionUrl)
                             deployment_details[u'entity'][u'asset']['href'] = scoringUrl
@@ -427,9 +429,14 @@ class Deployments(WMLResource):
                     )
                 return self._handle_response(200, "deployment", response)
             else:
-                return self._get_artifact_details(url, deployment_uid, limit, 'deployments')
+                deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments')
+                if "system" in deployment_details:
+                    print("Note: " + deployment_details['system']['warnings'][0]['message'])
+                return deployment_details
         else:
-            return self._get_artifact_details(url, deployment_uid, limit, 'deployments')
+            details = self._get_artifact_details(url, deployment_uid, limit, 'deployments')
+            
+            return details
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -1406,7 +1413,6 @@ class Deployments(WMLResource):
             params = {}
 
         if hard_delete is True:
-            params = {}
             params.update({'hard_delete': u'true'})
 
         if not self._ICP:
