@@ -13,15 +13,17 @@
 # limitations under the License.
 
 import logging
+import copy
 import sys
 from typing import List, Union
 
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
-    TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, PredictionType, Metrics, DataConnectionTypes,
-    PipelineTypes, PositiveLabelClass)
+    TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, PredictionType, Metrics, Transformers,
+    DataConnectionTypes, PipelineTypes, PositiveLabelClass)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel
-from ibm_watson_machine_learning.utils.autoai.utils import is_ipython, check_dependencies_versions
+from ibm_watson_machine_learning.utils.autoai.utils import is_ipython, check_dependencies_versions,\
+    validate_additional_params_for_optimizer
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -35,9 +37,6 @@ __all__ = [
 if is_ipython:
     logging.disable(sys.maxsize)
 
-# note: checking installed versions of scikit, xgboost and lightgbm
-check_dependencies_versions()
-
 
 class AutoAI(BaseExperiment):
     """
@@ -80,9 +79,11 @@ class AutoAI(BaseExperiment):
     TShirtSize = TShirtSize
     PredictionType = PredictionType
     Metrics = Metrics
+    Transformers = Transformers
     DataConnectionTypes = DataConnectionTypes
     PipelineTypes = PipelineTypes
 
+
     def __init__(self,
                  wml_credentials: Union[dict, 'WorkSpace'] = None,
                  project_id: str = None,
@@ -145,9 +146,10 @@ class AutoAI(BaseExperiment):
                   scoring: 'Metrics',
                   desc: str = None,
                   test_size: float = 0.1,
-                  max_number_of_estimators: int = 1,
+                  max_number_of_estimators: int = 2,
                   train_sample_rows_test_size: float = None,
                   daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                  cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
                   csv_separator: Union[List[str], str] = ',',
                   excel_sheet: Union[str, int] = 0,
@@ -181,7 +183,7 @@ class AutoAI(BaseExperiment):
         max_number_of_estimators: int, optional
             Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
             for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-            to use in pipeline composition.  The default is 1, where only the highest ranked by model
+            to use in pipeline composition.  The default is 2, where only the highest ranked by model
             selection algorithm type is used. (min 1, max 4)
 
         train_sample_rows_test_size: float, optional
@@ -191,6 +193,10 @@ class AutoAI(BaseExperiment):
             List of estimators to include in computation process.
             See: AutoAI.ClassificationAlgorithms or AutoAI.RegressionAlgorithms
 
+        cognito_transform_names: List['Transformers'], optional
+            List of transformers to include in feature enginnering computation process.
+            See: AutoAI.Transformers
+
         csv_separator: Union[List[str], str], optional
             The separator, or list of separators to try for separating
             columns in a CSV file.  Not used if the file_name is not a CSV file.
@@ -235,6 +241,7 @@ class AutoAI(BaseExperiment):
         >>>        desc="Some description.",
         >>>        test_size=0.1,
         >>>        max_num_daub_ensembles=1,
+        >>>        cognito_transform_names=[AutoAI.Transformers.SUM,AutoAI.Transformers.MAX],
         >>>        train_sample_rows_test_size=1,
         >>>        daub_include_only_estimators=[AutoAI.ClassificationAlgorithms.LGBM, AutoAI.ClassificationAlgorithms.XGB],
         >>>        t_shirt_size=AutoAI.TShirtSize.L
@@ -264,6 +271,14 @@ class AutoAI(BaseExperiment):
                        "\"t_shirt_size\" parameter is only applicable to the RemoteOptimizer instance."
             )
         elif self._workspace is None:
+            reduced_kwargs = copy.copy(kwargs)
+
+            for n in ['_force_local_scenario']:
+                if n in reduced_kwargs:
+                    del reduced_kwargs[n]
+
+            validate_additional_params_for_optimizer(reduced_kwargs)
+
             return LocalAutoPipelines(
                 name=name,
                 prediction_type='classification' if prediction_type in ['binary', 'multiclass'] else prediction_type,
@@ -274,11 +289,21 @@ class AutoAI(BaseExperiment):
                 max_num_daub_ensembles=max_number_of_estimators,
                 train_sample_rows_test_size=train_sample_rows_test_size,
                 daub_include_only_estimators=daub_include_only_estimators,
+                cognito_transform_names=cognito_transform_names,
                 positive_label=positive_label,
-                _force_local_scenario=kwargs.get('_force_local_scenario', False)
+                _force_local_scenario=kwargs.get('_force_local_scenario', False),
+                **reduced_kwargs
             )
 
         else:
+            reduced_kwargs = copy.copy(kwargs)
+
+            for n in ['t_shirt_size', 'notebooks', 'autoai_pod_version', 'obm_pod_version']:
+                if n in reduced_kwargs:
+                    del reduced_kwargs[n]
+
+            validate_additional_params_for_optimizer(reduced_kwargs)
+
             optimizer = RemoteAutoPipelines(
                 name=name,
                 prediction_type=prediction_type,
@@ -292,6 +317,7 @@ class AutoAI(BaseExperiment):
                 ),
                 train_sample_rows_test_size=train_sample_rows_test_size,
                 daub_include_only_estimators=daub_include_only_estimators,
+                cognito_transform_names=cognito_transform_names,
                 data_join_graph=data_join_graph,
                 csv_separator=csv_separator,
                 excel_sheet=excel_sheet,
@@ -301,7 +327,8 @@ class AutoAI(BaseExperiment):
                 engine=WMLEngine(self._workspace),
                 notebooks=kwargs.get('notebooks', True),
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
-                obm_pod_version=kwargs.get('obm_pod_version', None)
+                obm_pod_version=kwargs.get('obm_pod_version', None),
+                **reduced_kwargs
             )
             optimizer._workspace = self._workspace
             return optimizer
