@@ -15,14 +15,15 @@
 from typing import TYPE_CHECKING, List, Dict
 
 from pandas import DataFrame, MultiIndex
+import json
 
 from ibm_watson_machine_learning.utils.autoai.enums import (
     PredictionType, RegressionAlgorithms, ClassificationAlgorithms)
 from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType
 from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
-    fetch_pipelines, is_ipython, RunDetailsGenerator, check_dependencies_versions, try_import_autoai_libs,
-    create_summary)
+    fetch_pipelines, is_ipython, ProgressGenerator, check_dependencies_versions, try_import_autoai_libs,
+    create_summary, prepare_auto_ai_model_to_publish_normal_scenario, get_sw_spec_and_type_based_on_sklearn)
 from .base_engine import BaseEngine
 
 if TYPE_CHECKING:
@@ -103,6 +104,8 @@ class WMLEngine(BaseEngine):
                                 'max_num_daub_ensembles': self._auto_pipelines_parameters.get('max_num_daub_ensembles'),
                                 "daub_include_only_estimators":
                                     self._auto_pipelines_parameters.get('daub_include_only_estimators'),
+                                'cognito_transform_names':
+                                    self._auto_pipelines_parameters.get('cognito_transform_names'),
                                 'scorer_for_ranking': self._auto_pipelines_parameters.get('scoring'),
                                 'compute_pipeline_notebooks_flag': self._auto_pipelines_parameters.get('notebooks',
                                                                                                        False),
@@ -129,7 +132,7 @@ class WMLEngine(BaseEngine):
 
         # note: in new v4 api we have missing hw_spec name
         t_size = self._auto_pipelines_parameters['t_shirt_size']
-        if len(t_size) == 1:
+        if 0 < len(t_size) <= 2:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['runtimes'][0][
                 'app_data']['wml_data']['hardware_spec']['name'] = t_size.upper()
 
@@ -295,7 +298,7 @@ class WMLEngine(BaseEngine):
     ##########################################################
     #   WML Pipeline Part / AutoPipelineOptimizer Init Part  #
     ##########################################################
-    def initiate_remote_resources(self, params: dict) -> None:
+    def initiate_remote_resources(self, params: dict, **kwargs) -> None:
         """
         Initializes the AutoPipelines with supplied parameters.
 
@@ -306,7 +309,7 @@ class WMLEngine(BaseEngine):
         """
         self._auto_pipelines_parameters = params
         self._initialize_wml_pipeline_metadata()
-        self._wml_stored_pipeline_details = self._wml_client.pipelines.store(meta_props=self._wml_pipeline_metadata)
+        self._wml_stored_pipeline_details = self._wml_client.pipelines.store(meta_props=self._wml_pipeline_metadata, **kwargs)
 
     def get_params(self) -> dict:
         """
@@ -352,80 +355,94 @@ class WMLEngine(BaseEngine):
         run_params = self._wml_client.training.run(meta_props=self._wml_training_metadata,
                                                    asynchronous=True)
 
-        self._current_run_id = run_params['metadata']['guid']
-
-        wml_pipeline_details = self.get_params()
-
         if background_mode:
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
         else:
+            self._current_run_id = run_params['metadata']['guid']
+            wml_pipeline_details = self.get_params()
+            number_of_estimators = wml_pipeline_details.get('max_num_daub_ensembles', 2)
 
-            # TODO: Watson Studio does not support ipython widgets, this should be removed in the future
-            if is_ipython() and False:
-                # note: only notebook version
-                total = 100 * int(wml_pipeline_details.get('max_num_daub_ensembles', 1))
-                end = False
-                progress_bar_1 = ProgressBar(desc="Total", total=total, position=0, ncols='100%')
-                while not end:
-                    progress_bar_2 = ProgressBar(desc="Waiting", total=total, leave=False, ncols='100%')
-                    run_details_generator = RunDetailsGenerator(wml_client=self._wml_client,
-                                                                run_id=self._current_run_id,
-                                                                wait_time=0.5)
+            base_url = self._wml_client.service_instance._href_definitions.get_trainings_href()
+            url = f"{base_url.replace('https', 'wss')}/{self._current_run_id}"
 
-                    for message in run_details_generator:
-                        progress_bar_2.set_description(desc=message)
-                        if total - progress_bar_2.counter <= 2:
-                            pass
+            if self._wml_client.default_project_id:
+                url = f"{url}?project_id={self._wml_client.default_project_id}"
+            elif self._wml_client.default_space_id:
+                url = f"{url}?space_id={self._wml_client.default_space_id}"
 
-                        else:
-                            progress_bar_2.increment_counter(progress=1)
-                            progress_bar_2.update()
+            from lomond import WebSocket
+            websocket = WebSocket(url)
 
-                        if self._current_run_id in message:
-                            end = True
-                            progress_bar_1.last_update()
-                            progress_bar_1.set_description(desc=message)
-                            break
+            websocket.add_header(bytes("Authorization", "utf-8"),
+                                 bytes("Bearer " + self._wml_client.service_instance._get_token(), "utf-8"))
 
-                    progress_bar_2.last_update()
-                    progress_bar_2.close()
-                    if total - progress_bar_1.counter <= 10:
+            gen = ProgressGenerator(number_of_estimators)
+            end = False
+
+            progress_bar = ProgressBar(desc="Total", total=gen.get_total(), position=0, ncols=100, bar_format=None)
+
+            texts = {}
+
+            while not end:
+                progress_bar.set_description(desc='Started waiting for resources')
+                for event in websocket.connect():
+                    try:
+                        websocket.send_text('Ping')
+                    except:
                         pass
+                    if event.name == 'text':
+                        status = json.loads(event.text)['entity']['status']
+                        if 'message' in status and 'text' in status['message']:
+                            text = status['message']['text']
 
-                    else:
-                        progress_bar_1.increment_counter(progress=5)
-                        progress_bar_1.update()
-                progress_bar_1.close()
+                            try:
+                                phase = status['metrics'][0]['context']['phase']
+                            except:
+                                phase = ""
 
-            # note: only console version
-            else:
-                total = 200 * int(wml_pipeline_details.get('max_num_daub_ensembles', 1))
-                if self._auto_pipelines_parameters['data_join_graph']:
-                    total = total * 2  # make progress bar larger when we are using OBM + KB
+                            try:
+                                step_name = status['metrics'][0]['context']['step']['name']
+                            except:
+                                step_name = ""
 
-                progress_bar = ProgressBar(desc="Total", total=total, position=0, ncols=100)
-                end = False
-                while not end:
-                    run_details_generator = RunDetailsGenerator(wml_client=self._wml_client,
-                                                                run_id=self._current_run_id,
-                                                                wait_time=0.5)
+                            try:
+                                step_estimator = status['metrics'][0]['context']['step']['estimator']
+                            except:
+                                step_estimator = ""
 
-                    for message in run_details_generator:
-                        progress_bar.set_description(desc=message)
-                        if total - progress_bar.counter <= 5:
-                            pass
+                            log = f"{phase}:{step_name}:{step_estimator}:{text}"
 
-                        else:
-                            progress_bar.increment_counter(progress=1)
+                            if log not in texts:
+                                texts[log] = 1
+                            else:
+                                texts[log] = texts[log] + 1
+
+                            if self._current_run_id in text and 'completed' in text:
+                                end = True
+                                progress_bar.set_description(desc=text)
+                                progress_bar.last_update()
+                                progress_bar.close()
+                                break
+                            elif 'AutoAI model computed' not in text:
+                                prepared_text = text.split(': ')[-1].split("global:")[-1]
+                                max_len = 40
+
+                                if len(prepared_text) > max_len:
+                                    progress_bar.set_description(desc=prepared_text[:(max_len-3)] + '...')
+                                else:
+                                    progress_bar.set_description(desc=prepared_text + ' '*(max_len-len(prepared_text)))
+
+                            progress_bar.increment_counter(gen.get_progress(log))
                             progress_bar.update()
+                    elif event.name in ['closing', 'disconnected']:
+                        end = True
+                        break
 
-                        if self._current_run_id in message:
-                            end = True
-                            progress_bar.last_update()
-                            progress_bar.close()
-                            break
+            #for t in texts:
+            #    print(f"{t}: {texts[t]}")
 
+            websocket.close()
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
     def get_run_status(self) -> str:
@@ -645,9 +662,31 @@ class WMLEngine(BaseEngine):
         Scikit-Learn pipeline.
         """
         try_import_autoai_libs()
-        check_dependencies_versions(lib_name='numpy', error=True)
 
         run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
+
+        try:
+            # note: get experiment information to retrieve Hybrid SW specs and look which scikit was used
+            _, request_json = prepare_auto_ai_model_to_publish_normal_scenario(
+                pipeline_model=pipeline_name,
+                run_params=run_params,
+                run_id=self._current_run_id,
+                wml_client=self._wml_client,
+                space_id=''
+            )
+
+            hybrid_sw_spec = request_json['hybrid_pipeline_software_specs'][-1]['name']
+            # below includes scikit version check
+            _, _ = get_sw_spec_and_type_based_on_sklearn(client=self._wml_client, spec=hybrid_sw_spec)
+            # --- end note
+        
+        # do nothing when we cannot find request.json on user COS
+        except Exception as e:
+            if 'HeadObject' in str(e):
+                pass
+            else:
+                raise e
+
         try:
             pipelines: Dict[str, 'Pipeline'] = fetch_pipelines(
                 run_params=run_params,
@@ -681,23 +720,5 @@ class WMLEngine(BaseEngine):
         -------
         Scikit-Learn pipeline.
         """
-        try_import_autoai_libs()
-        check_dependencies_versions(lib_name='numpy', error=True)
-
         best_pipeline_name = self.summary().index[0]
-        try:
-            pipelines: Dict[str, 'Pipeline'] = fetch_pipelines(
-                run_params=self._wml_client.training.get_details(training_uid=self._current_run_id),
-                path=local_path,
-                pipeline_name=best_pipeline_name,
-                load_pipelines=True,
-                store=persist,
-                wml_client=self._wml_client if self._wml_client.ICP else None
-            )
-
-        except Exception as e:
-            raise PipelineNotLoaded(
-                'Best Pipeline',
-                reason=f'Fit finished but there was some error during loading a pipeline from WML. Error: {e}')
-
-        return pipelines.get(best_pipeline_name)
+        return self.get_pipeline(best_pipeline_name)
