@@ -20,13 +20,13 @@ from numpy import ndarray
 from pandas import DataFrame
 
 from ibm_watson_machine_learning.helpers.connections import (
-    DataConnection, S3Location, FSLocation, CP4DAssetLocation, WMLSAssetLocation, WSDAssetLocation)
+    DataConnection, S3Location, FSLocation, AssetLocation, WSDAssetLocation)
 from ibm_watson_machine_learning.preprocessing import DataJoinPipeline
 from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
-    TrainingDataSourceIsNotFile, NoneDataConnection)
+    TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -35,7 +35,7 @@ from .base_auto_pipelines import BaseAutoPipelines
 
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.experiment.autoai.engines import WMLEngine
-    from ibm_watson_machine_learning.utils.autoai.enums import Metrics, PredictionType
+    from ibm_watson_machine_learning.utils.autoai.enums import Metrics, PredictionType, Transformers
     from ibm_watson_machine_learning.preprocessing import DataJoinGraph
     from sklearn.pipeline import Pipeline
 
@@ -80,6 +80,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
         List of estimators to include in computation process.
 
+    cognito_transform_names: List['Transformers'], optional
+        List of transformers to include in feature enginnering computation process.
+        See: AutoAI.Transformers
+
     csv_separator: Union[List[str], str], optional
             The separator, or list of separators to try for separating
             columns in a CSV file.  Not used if the file_name is not a CSV file.
@@ -120,6 +124,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  train_sample_rows_test_size: float = None,
                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 cognito_transform_names: List['Transformers'] = None,
                  data_join_graph: 'DataJoinGraph' = None,
                  csv_separator: Union[List[str], str] = ',',
                  excel_sheet: Union[str, int] = 0,
@@ -128,7 +133,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  data_join_only: bool = False,
                  notebooks=False,
                  autoai_pod_version=None,
-                 obm_pod_version=None):
+                 obm_pod_version=None,
+                 **kwargs):
         self.params = {
             'name': name,
             'desc': desc if desc else '',
@@ -140,6 +146,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             't_shirt_size': t_shirt_size,
             'train_sample_rows_test_size': train_sample_rows_test_size,
             'daub_include_only_estimators': daub_include_only_estimators,
+            'cognito_transform_names': cognito_transform_names,
             'data_join_graph': data_join_graph or False,
             'csv_separator': csv_separator,
             'excel_sheet': excel_sheet,
@@ -151,7 +158,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'obm_pod_version': obm_pod_version,
         }
         self._engine: 'WMLEngine' = engine
-        self._engine.initiate_remote_resources(params=self.params)
+        self._engine.initiate_remote_resources(params=self.params, **kwargs)
         self.best_pipeline = None
         self._workspace = None
 
@@ -265,6 +272,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         if None in training_data_reference:
             raise NoneDataConnection('training_data_reference')
 
+        for conn in training_data_reference:
+            if conn.type == DataConnectionTypes.S3:
+                conn._validate_cos_resource()
+
         training_data_reference = [new_conn for conn in training_data_reference for new_conn in conn._subdivide_connection()]
 
         # note: check if DataJoinGraph node names are correct and equivalent
@@ -314,8 +325,13 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                     location.path = location.path.format(option='spaces',
                                                          id=self._engine._wml_client.default_space_id)
                 else:
-                    location.path = location.path.format(option='projects',
-                                                         id=self._engine._wml_client.default_project_id)
+                    if self._workspace.wml_client.default_project_id is None:
+                        location.path = location.path.format(option='spaces',
+                                                             id=self._engine._wml_client.default_space_id)
+
+                    else:
+                        location.path = location.path.format(option='projects',
+                                                             id=self._engine._wml_client.default_project_id)
                 training_results_reference = DataConnection(
                     connection=None,
                     location=location
@@ -336,7 +352,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                                       training_results_reference=training_results_reference,
                                       background_mode=background_mode)
 
-        if isinstance(training_data_reference[0].location, WSDAssetLocation):
+        if isinstance(training_data_reference[0].location, WSDAssetLocation) or (isinstance(training_data_reference[0].location, AssetLocation) and training_data_reference[0].location._wsd):
             try:
                 wml_pipeline_details = self._workspace.wml_client.pipelines.get_details(
                     run_params['entity']['pipeline']['id'])
@@ -502,11 +518,17 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             try_import_lale()
         # --- end note
 
-        if pipeline_name is None:
-            pipeline_model = self._engine.get_best_pipeline(persist=persist)
+        try:
+            if pipeline_name is None:
+                pipeline_model = self._engine.get_best_pipeline(persist=persist)
 
-        else:
-            pipeline_model = self._engine.get_pipeline(pipeline_name=pipeline_name, persist=persist)
+            else:
+                pipeline_model = self._engine.get_pipeline(pipeline_name=pipeline_name, persist=persist)
+
+        except Exception as e:
+            raise PipelineNotLoaded(pipeline_name if pipeline_name is not None else 'best pipeline',
+                                    reason=f"Pipeline with such a name probably does not exist. "
+                                           f"Please make sure you specify correct pipeline name. Error: {e}")
 
         if astype == PipelineTypes.SKLEARN:
             return pipeline_model
