@@ -25,7 +25,7 @@ from ibm_watson_machine_learning.experiment.autoai.engines import WMLEngine
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.utils import NextRunDetailsGenerator, get_node_and_runtime_index
-from ibm_watson_machine_learning.helpers import DataConnection
+from ibm_watson_machine_learning.helpers import DataConnection, S3Location
 from .base_auto_pipelines_runs import BaseAutoPipelinesRuns
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
@@ -84,17 +84,17 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         # --- end note
 
         for wml_pipeline_id in runs_pipeline_ids:
-            pipeline_details = self._wml_engine._wml_client.pipelines.get_details(
-                pipeline_uid=wml_pipeline_id)
+            try:
+                pipeline_details = self._wml_engine._wml_client.pipelines.get_details(
+                    pipeline_uid=wml_pipeline_id)
+
+            except ApiRequestFailure:
+                pipeline_details = {'metadata': {'name': 'Experiment data is missing...'}}
 
             wml_pipeline_type = ('autoai' if 'automl' in str(pipeline_details) and
                                              'hybrid' in str(pipeline_details) else 'other')
 
-            try:
-                wml_pipeline_name = pipeline_details['metadata'].get('name')
-
-            except ApiRequestFailure as e:
-                wml_pipeline_name = 'Unknown'
+            wml_pipeline_name = pipeline_details['metadata'].get('name', 'Unknown')
 
             wml_pipelines_names.append(wml_pipeline_name)
             wml_pipelines_types.append(wml_pipeline_type)
@@ -202,6 +202,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'max_num_daub_ensembles': kb_parameters['max_num_daub_ensembles'],
                 't_shirt_size': kb_wml_data['hardware_spec']['id'],
                 'daub_include_only_estimators': kb_parameters.get('daub_include_only_estimators'),
+                'cognito_transform_names': kb_parameters.get('cognito_transform_names'),
                 'train_sample_rows_test_size': kb_parameters.get('train_sample_rows_test_size'),
                 'csv_separator': csv_separator,
                 'excel_sheet': excel_sheet,
@@ -308,11 +309,18 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             return remote_pipeline_optimizer
         # --- end note
 
-        # note: WSD auto-gen notebook scenario (when user provides his WMLS credentials)
+        # note: WSD / Cloud auto-gen notebook scenario (when user provides his WMLS credentials)
         else:
             from ibm_watson_machine_learning.experiment import AutoAI
             training_result_reference = metadata.get('training_result_reference')
-            run_id = training_result_reference.location.path.split('/')[-3]
+
+            # note: check for cloud
+            if isinstance(training_result_reference.location, S3Location):
+                run_id = training_result_reference.location._training_status.split('/')[-2]
+
+            # WMLS
+            else:
+                run_id = training_result_reference.location.path.split('/')[-3]
 
             # note: CP4D notebook scenario
             if self._wml_engine is not None:
