@@ -119,7 +119,7 @@ class Experiments(WMLResource):
             if self._client.CLOUD_PLATFORM_SPACES:
                 response_experiment_post = requests.post(
                     self._href_definitions.get_experiments_href(),
-                    params=self._client._params(),
+                    params=self._client._params(skip_for_create=True),
                     json=metaProps,
                     headers=self._client._get_headers()
                 )
@@ -134,7 +134,7 @@ class Experiments(WMLResource):
                 response_experiment_post = requests.post(
                     self._href_definitions.get_experiments_href(),
                     json=metaProps,
-                    params=self._client._params(),
+                    params=self._client._params(skip_for_create=True),
                     headers=self._client._get_headers(),
                     verify=False
                 )
