@@ -57,7 +57,7 @@ class Functions(WMLResource):
            **Parameters**
 
            .. important::
-                #. **meta_props**:  meta data or name of the function. To see available meta names use **client.functions.ConfigurationMetaNames.get()**\n
+                #. **meta_props**:  meta data or name of the function. To see available meta names use **client._functions.ConfigurationMetaNames.show()**\n
                    **type**: str or dict\n
                 #. **function**:  path to file with archived function content or function (as described above)\n
                    **type**: str or function\n
@@ -72,13 +72,18 @@ class Functions(WMLResource):
 
             The most simple use is (using `score` function):
 
-            >>> def score(payload):
-            >>>      values = [[row[0]*row[1]] for row in payload['values']]
-            >>>      return {'fields': ['multiplication'], 'values': values}
-            >>> stored_function_details = client.functions.store(score, name)
+             >>> meta_props = {
+             >>>    client._functions.ConfigurationMetaNames.NAME: "function",
+             >>>    client._functions.ConfigurationMetaNames.DESCRIPTION: "This is ai function",
+             >>>    client._functions.ConfigurationMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
 
-            Other, more interesting example is using generator function.
-            In this situation it is possible to pass some variables:
+             >>> def score(payload):
+             >>>      values = [[row[0]*row[1]] for row in payload['values']]
+             >>>      return {'fields': ['multiplication'], 'values': values}
+             >>> stored_function_details = client._functions.store(score, meta_props)
+
+             Other, more interesting example is using generator function.
+             In this situation it is possible to pass some variables:
 
                 >>> wml_creds = {...}
                 >>> def gen_function(wml_credentials=wml_creds, x=2):
@@ -86,18 +91,7 @@ class Functions(WMLResource):
                             values = [[row[0]*row[1]*x] for row in payload['values']]
                             return {'fields': ['multiplication'], 'values': values}
                         return f
-                >>> stored_function_details = client.functions.store(gen_function, name)
-
-            In more complicated cases you should create proper metadata, similar to this one:
-
-                >>> metadata = {
-                >>>    client.repository.FunctionMetaNames.NAME: "function",
-                >>>    client.repository.FunctionMetaNames.DESCRIPTION: "This is ai function",
-                >>>    client.repository.FunctionMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f",
-                >>>    client.repository.FunctionMetaNames.INPUT_DATA_SCHEMAS: [{"fields": [{"metadata": {}, "type": "string", "name": "GENDER", "nullable": True}]}],
-                >>>    client.repository.FunctionMetaNames.OUTPUT_DATA_SCHEMAS:[{"fields": [{"metadata": {}, "type": "string", "name": "GENDER", "nullable": True}]}],
-                >>> }
-                >>> stored_function_details = client.functions.store(score, metadata)
+                >>> stored_function_details = client._functions.store(gen_function, meta_props)
             """
         self._client._check_if_either_is_set()
 
@@ -319,7 +313,7 @@ score = {}()
                     if self._client.CLOUD_PLATFORM_SPACES:
                         response_post = requests.post(self._href_definitions.get_functions_href(),
                                                       json=function_metadata,
-                                                      params=self._client._params(),
+                                                      params=self._client._params(skip_for_create=True),
                                                       headers=self._client._get_headers())
                     else:
                         response_post = requests.post(self._href_definitions.get_functions_href(),
@@ -329,7 +323,7 @@ score = {}()
                     if self._client.ICP_PLATFORM_SPACES:
                         response_post = requests.post(self._href_definitions.get_functions_href(),
                                                       json=function_metadata,
-                                                      params=self._client._params(),
+                                                      params=self._client._params(skip_for_create=True),
                                                       headers=self._client._get_headers(),
                                                       verify=False)
                     else:
@@ -399,9 +393,9 @@ score = {}()
 
         **Example**
          >>> metadata = {
-         >>> client.functions.ConfigurationMetaNames.NAME:"updated_function"
+         >>> client._functions.ConfigurationMetaNames.NAME:"updated_function"
          >>> }
-         >>> function_details = client.functions.update(function_uid, changes=metadata)
+         >>> function_details = client._functions.update(function_uid, changes=metadata)
 
         """
         if self._client.WSD:
@@ -478,11 +472,13 @@ score = {}()
 
                     code[0] = new_header
                     code = '\n'.join(code)
-                    file_content = """
-        {}
 
-        score = {}()
-        """.format(code, function.__name__)
+                    file_content = """
+{}
+
+score = {}()
+""".format(code, function.__name__)
+
                 else:
                     raise WMLClientError(
                         "Function passed is not \'score\' function nor generator function. Generator function should have no arguments or all arguments with primitive python default values.")
@@ -557,7 +553,7 @@ score = {}()
 
             **Example**
 
-             >>> client.functions.download(function_uid, 'my_func.tar.gz')
+             >>> client._functions.download(function_uid, 'my_func.tar.gz')
         """
         self._client._check_if_either_is_set()
 
@@ -653,12 +649,17 @@ score = {}()
 
             **Example**
 
-             >>> client.functions.delete(function_uid)
+             >>> client._functions.delete(function_uid)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
         function_uid = str_type_conv(function_uid)
         Functions._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
+                self._if_deployment_exist_for_asset(function_uid):
+            raise WMLClientError(
+                u'Cannot delete function that has existing deployments. Please delete all associated deployments and try again')
+
         ##TODO_V4 Uncomment this after deployments is ready
         # Delete associated deployments, so there will be no orphans
         # if not self._client.default_project_id:
@@ -741,8 +742,8 @@ score = {}()
 
            **Example**
 
-             >>> function_details = client.functions.get_details(function_uid)
-             >>> function_details = client.functions.get_details()
+             >>> function_details = client._functions.get_details(function_uid)
+             >>> function_details = client._functions.get_details()
          """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -781,7 +782,7 @@ score = {}()
                 **Example**
 
                  >>> function_details = client.repository.get_function_details(function_uid)
-                 >>> function_id = client.functions.get_id(function_details)
+                 >>> function_id = client._functions.get_id(function_details)
         """
 
         return Functions.get_uid(function_details)
@@ -809,7 +810,7 @@ score = {}()
                 **Example**
 
                  >>> function_details = client.repository.get_function_detailsf(function_uid)
-                 >>> function_uid = client.functions.get_uid(function_details)
+                 >>> function_uid = client._functions.get_uid(function_details)
         """
         Functions._validate_type(function_details, u'function_details', object, True)
         if 'asset_id' in function_details['metadata']:
@@ -845,7 +846,7 @@ score = {}()
            **Example**
 
              >>> function_details = client.repository.get_function_detailsf(function_uid)
-             >>> function_url = client.functions.get_href(function_details)
+             >>> function_url = client._functions.get_href(function_details)
         """
         Functions._validate_type(function_details, u'function_details', object, True)
         if 'asset_type' in function_details['metadata']:
@@ -879,7 +880,7 @@ score = {}()
 
            **Example**
 
-            >>> client.functions.list()
+            >>> client._functions.list()
         """
         ##For CP4D, check if either spce or project ID is set
 
@@ -935,7 +936,7 @@ score = {}()
                         **return type**: dict\n
 
                 **Example**
-                 >>> client.functions.clone(function_uid=artifact_id,space_id=space_uid,action="copy")
+                 >>> client._functions.clone(function_uid=artifact_id,space_id=space_uid,action="copy")
 
                 .. note::
                     * If revision id is not specified, all revisions of the artifact are cloned\n
@@ -986,7 +987,7 @@ score = {}()
 
             Example:
 
-            >>> client.functions.create_revision(pipeline_uid)
+            >>> client._functions.create_revision(pipeline_uid)
         """
         function_uid = str_type_conv(function_uid)
         Functions._validate_type(function_uid, u'pipeline_uid', STR_TYPE, False)
@@ -1013,7 +1014,7 @@ score = {}()
 
            Example:
 
-           >>> function_revision_details = client.functions.get_details(function_uid, rev_uid)
+           >>> function_revision_details = client._functions.get_details(function_uid, rev_uid)
         """
         self._client._check_if_either_is_set()
         model_uid = str_type_conv(function_uid)
@@ -1042,7 +1043,7 @@ score = {}()
            :returns:   list all function revisions details.
            :rtype: table
 
-           >>> model_details = client.functions.list_revisions(function_uid)
+           >>> details = client._functions.list_revisions(function_uid)
         """
         self._client._check_if_either_is_set()
         function_uid = str_type_conv(function_uid)
