@@ -24,15 +24,15 @@ from abc import ABC, abstractmethod
 from typing import Union, Tuple, TYPE_CHECKING
 
 import requests
-from pandas import concat
+from pandas import concat, DataFrame
 
 from ibm_watson_machine_learning.utils.autoai.utils import try_load_dataset
 from ibm_watson_machine_learning.utils.autoai.enums import DataConnectionTypes
+from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
 
 if TYPE_CHECKING:
-    from pandas import DataFrame
     from ibm_boto3 import resource
 
 
@@ -116,7 +116,7 @@ class BaseDataConnection(ABC):
         # --- end note
         return data
 
-    def _download_obm_json_from_cos(self) -> dict:
+    def _download_obm_json(self) -> dict:
         """Download obm.json log. COS version."""
         data = {}
 
@@ -132,9 +132,24 @@ class BaseDataConnection(ABC):
                 raise ConnectionError(
                     f"Unable to access data object in cloud object storage with credentials supplied. "
                     f"Error: {cos_access_exception}")
+        elif self.type == DataConnectionTypes.FS and self._obm:
+            # note: fetch all OBM file part names
+            obm_json_url = f"{self._wml_client.wml_credentials['url']}/v2/asset_files/auto_ml/{self.location.path.split('/auto_ml/')[-1]}/{self._run_id}/data/obm/obm.json"
+            file_response = requests.get(obm_json_url,
+                                         params=self._wml_client._params(),
+                                         headers=self._wml_client._get_headers(),
+                                         stream=True,
+                                         verify=False)
 
+            if file_response.status_code != 200:
+                raise ApiRequestFailure(u'Failure during {}.'.format("downloading obm json"), file_response)
+
+            downloaded_asset = file_response.content
+            # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+            buffer = io.BytesIO(downloaded_asset)
+            data = json.loads(buffer.getvalue().decode('utf-8'))
         else:
-            raise NotImplementedError("OBM is not supported for CP4D and WML Server yet.")
+            raise NotImplementedError("OBM is not supported for WML Server yet.")
 
         return data
 
@@ -155,6 +170,10 @@ class BaseDataConnection(ABC):
     def _download_training_data_from_data_asset_storage(self) -> 'DataFrame':
         """Download training data for this connection. Data Storage."""
 
+        # it means that it is on ICP env and it is before fit, so let's throw error
+        if not self._wml_client:
+            raise CannotReadSavedRemoteDataBeforeFit()
+
         # note: as we need to load a data into the memory,
         # we are using pure requests and helpers from the WML client
         asset_id = self.location.href.split('?')[0].split('/')[-1]
@@ -168,33 +187,40 @@ class BaseDataConnection(ABC):
         asset_details = self._wml_client.data_assets._handle_response(200, u'get assets', asset_response)
 
         # note: read the csv url
-        attachment_url = asset_details['attachments'][0]['handle']['key']
+        if 'handle' in asset_details['attachments'][0]:
+            attachment_url = asset_details['attachments'][0]['handle']['key']
 
-        # note: make the whole url pointing out the csv
-        artifact_content_url = (f"{self._wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}"
-                                f"{attachment_url}")
+            # note: make the whole url pointing out the csv
+            artifact_content_url = (f"{self._wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}"
+                                    f"{attachment_url}")
 
-        # note: stream the whole CSV file
-        csv_response = requests.get(artifact_content_url,
-                                    params=self._wml_client._params(),
-                                    headers=self._wml_client._get_headers(),
-                                    stream=True,
-                                    verify=False)
+            # note: stream the whole CSV file
+            csv_response = requests.get(artifact_content_url,
+                                        params=self._wml_client._params(),
+                                        headers=self._wml_client._get_headers(),
+                                        stream=True,
+                                        verify=False)
 
-        if csv_response.status_code != 200:
-            raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+            if csv_response.status_code != 200:
+                raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
 
-        downloaded_asset = csv_response.content
+            downloaded_asset = csv_response.content
 
-        # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
-        buffer = io.BytesIO(downloaded_asset)
-        data = try_load_dataset(buffer=buffer,
-                                sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
-                                separator=self.auto_pipeline_params.get('csv_separator', ','),
-                                encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
-                                )
+            # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+            buffer = io.BytesIO(downloaded_asset)
+            data = try_load_dataset(buffer=buffer,
+                                    sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
+                                    separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                    encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                    )
 
-        return data
+            return data
+        else:
+            # NFS scenario
+            connection_id = asset_details['attachments'][0]['connection_id']
+            connection_path = asset_details['attachments'][0]['connection_path']
+
+            return self._download_data_from_nfs_connection_using_id_and_path(connection_id, connection_path)
 
     def _download_training_data_from_file_system(self) -> 'DataFrame':
         """Download training data for this connection. File system version."""
@@ -228,3 +254,89 @@ class BaseDataConnection(ABC):
                                         )
 
         return data
+
+    def _download_obm_data_from_file_system(self) -> 'DataFrame':
+        """Download preprocessed OBM data. FS version."""
+
+        # note: fetch all OBM file part names
+        url = f"{self._wml_client.wml_credentials['url']}/v2/asset_files/auto_ml/{self.location.path.split('/auto_ml/')[-1]}/{self._run_id}/data/obm/features"
+        params = self._wml_client._params()
+        params['flat'] = "true"
+
+        response = requests.get(url,
+                                params=params,
+                                headers=self._wml_client._get_headers(),
+                                verify=False)
+
+        if response.status_code != 200:
+            raise ApiRequestFailure(u'Failure during {}.'.format("getting files information"), response)
+
+        file_names = [e['path'].split('/')[-1] for e in response.json()['resources'] if e['type'] == 'file' and e['path'].split('/')[-1].startswith('part')]
+
+        # TODO: this can be done simultaneously (multithreading / multiprocessing)
+        # note: download all data parts and concatenate them into one output
+        parts = []
+        for file_name in file_names:
+            csv_response = requests.get(url + '/' + file_name,
+                                        params=self._wml_client._params(),
+                                        headers=self._wml_client._get_headers(),
+                                        stream=True,
+                                        verify=False)
+
+            if csv_response.status_code != 200:
+                raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+
+            downloaded_asset = csv_response.content
+            # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+            buffer = io.BytesIO(downloaded_asset)
+            parts.append(try_load_dataset(buffer=buffer))
+
+        data = concat(parts)
+        # --- end note
+        return data
+
+    def _download_data_from_nfs_connection(self) -> 'DataFrame':
+        """Download training data for this connection. NFS."""
+
+        # note: as we need to load a data into the memory,
+        # we are using pure requests and helpers from the WML client
+        data_path = self.location.path
+        connection_id = self.connection.asset_id
+
+        return self._download_data_from_nfs_connection_using_id_and_path(connection_id, data_path)
+
+    def _download_data_from_nfs_connection_using_id_and_path(self, connection_id, connection_path) -> 'DataFrame':
+        """Download training data for this connection. NFS."""
+
+        # it means that it is on ICP env and it is before fit, so let's throw error
+        if not self._wml_client:
+            raise CannotReadSavedRemoteDataBeforeFit()
+
+        # note: download data asset details
+        href = self._wml_client.connections._href_definitions.get_connection_by_id_href(connection_id) + '/assets'
+        params = self._wml_client._params().copy()
+        params['path'] = connection_path
+        params['fetch'] = 'metadata'
+        nfs_response = requests.get(href,
+                                    params=params,
+                                    headers=self._wml_client._get_headers(),
+                                    verify=False)
+
+        asset_details = self._wml_client.data_assets._handle_response(200, u'get nfs asset', nfs_response)
+
+        # note: read the column names of dataset
+        dataset_columns = [column['name'] for column in asset_details['fields']]
+
+        # note: stream the whole CSV file
+        params['fetch'] = 'data'
+        csv_response = requests.get(href,
+                                    params=params,
+                                    headers=self._wml_client._get_headers(),
+                                    verify=False)
+
+        if csv_response.status_code != 200:
+            raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+
+        data = DataFrame(csv_response.json()['data'], columns=dataset_columns)
+
+        return data
