@@ -17,12 +17,14 @@ __all__ = [
     "S3Connection",
     "S3Location",
     "FSLocation",
-    "DSLocation",
+    "AssetLocation",
     "CP4DAssetLocation",
     "WMLSAssetLocation",
     "WSDAssetLocation",
     "CloudAssetLocation",
-    "DeploymentOutputAssetLocation"
+    "DeploymentOutputAssetLocation",
+    "NFSConnection",
+    "NFSLocation"
 ]
 
 import io
@@ -41,7 +43,8 @@ import requests
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, DataConnectionTypes
 from ibm_watson_machine_learning.utils.autoai.errors import (
     MissingAutoPipelinesParameters, UseWMLClient, MissingCOSStudioConnection, MissingProjectLib,
-    HoldoutSplitNotSupported, InvalidCOSCredentials, MissingLocalAsset, InvalidIdType
+    HoldoutSplitNotSupported, InvalidCOSCredentials, MissingLocalAsset, InvalidIdType, NotWSDEnvironment,
+    NotExistingCOSResource
 )
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure
@@ -62,7 +65,7 @@ class DataConnection(BaseDataConnection):
     connection: Union[S3Connection], required
         connection parameters of specific type
 
-    location: Union[S3Location, FSLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation],
+    location: Union[S3Location, FSLocation, AssetLocation],
         required location parameters of specific type
 
     data_join_node_name: Union[str, List[str]], optional
@@ -74,27 +77,34 @@ class DataConnection(BaseDataConnection):
     def __init__(self,
                  location: Union['S3Location',
                                  'FSLocation',
+                                 'AssetLocation',
                                  'CP4DAssetLocation',
                                  'WMLSAssetLocation',
                                  'WSDAssetLocation',
                                  'CloudAssetLocation',
+                                 'NFSLocation',
                                  'DeploymentOutputAssetLocation'],
-                 connection: Optional['S3Connection'] = None,
+                 connection: Optional[Union['S3Connection', 'NFSConnection']] = None,
                  data_join_node_name: Union[str, List[str]] = None):
         super().__init__()
 
+        self.connection = connection
+        self.location = location
+
         if isinstance(connection, S3Connection):
             self.type = DataConnectionTypes.S3
 
+        elif isinstance(location, NFSLocation):
+            self.type = DataConnectionTypes.CA
+            if self.connection is not None:
+                self.location.id = self.connection.asset_id
+
         elif isinstance(location, FSLocation):
             self.type = DataConnectionTypes.FS
 
-        elif isinstance(location, (CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation)):
+        elif isinstance(location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation)):
             self.type = DataConnectionTypes.DS
 
-        self.connection = connection
-        self.location = location
-
         self.auto_pipeline_params = {}  # note: needed parameters for recreation of autoai holdout split
         self._wml_client = None
         self._run_id = None
@@ -242,16 +252,14 @@ class DataConnection(BaseDataConnection):
             data_connection: 'DataConnection' = cls(
                 location=FSLocation._set_path(path=_dict['location']['path'])
             )
-
-        else:
-            # note: recognizing environment by location href
-            if 'project_id=' in _dict['location']['href']:
-                asset_location = CP4DAssetLocation._set_path(href=_dict['location']['href'])
-            else:
-                asset_location = WMLSAssetLocation._set_path(href=_dict['location']['href'])
-            # --- end note
+        elif _dict['type'] == DataConnectionTypes.CA:
             data_connection: 'DataConnection' = cls(
-                location=asset_location
+                connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
+                location=NFSLocation(path=_dict['location']['path'])
+            )
+        else:
+            data_connection: 'DataConnection' = cls(
+                location=AssetLocation._set_path(href=_dict['location']['href'])
             )
 
         if _dict.get('id'):
@@ -333,7 +341,14 @@ class DataConnection(BaseDataConnection):
             data = self._download_training_data_from_data_asset_storage()
 
         elif self.type == DataConnectionTypes.FS:
-            data = self._download_training_data_from_file_system()
+
+            if self._obm:
+                data = self._download_obm_data_from_file_system()
+            else:
+                data = self._download_training_data_from_file_system()
+
+        elif self.type == DataConnectionTypes.CA:
+            data = self._download_data_from_nfs_connection()
 
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
@@ -443,6 +458,14 @@ class DataConnection(BaseDataConnection):
             )
         return cos_client
 
+    def _validate_cos_resource(self):
+        cos_client = self._init_cos_client()
+        try:
+            files = cos_client.Bucket(self.location.bucket).objects.all()
+            next(x for x in files if x.key == self.location.path)
+        except Exception as e:
+            raise NotExistingCOSResource(self.location.bucket, self.location.path)
+
 
 class S3Connection(BaseConnection):
     """
@@ -471,8 +494,6 @@ class S3Connection(BaseConnection):
 
     def __init__(self, endpoint_url: str, access_key_id: str = None, secret_access_key: str = None,
                  api_key: str = None, service_name: str = None, auth_endpoint: str = None) -> None:
-        self.endpoint_url = endpoint_url
-        self.access_key_id = access_key_id
 
         if (access_key_id is None or secret_access_key is None) and (api_key is None or auth_endpoint is None):
             raise InvalidCOSCredentials(reason='You need to specify (access_key_id and secret_access_key) or'
@@ -490,6 +511,12 @@ class S3Connection(BaseConnection):
         if auth_endpoint is not None:
             self.auth_endpoint = auth_endpoint
 
+        if access_key_id is not None:
+            self.access_key_id = access_key_id
+
+        if endpoint_url is not None:
+            self.endpoint_url = endpoint_url
+
 
 class S3Location(BaseLocation):
     """
@@ -535,7 +562,7 @@ class FSLocation(BaseLocation):
 
     def __init__(self, path: Optional[str] = None) -> None:
         if path is None:
-            self.path = "{option}/{id}" + f"/assets/auto_ml/auto_ml.{uuid.uuid4()}/wml_data"
+            self.path = "/{option}/{id}" + f"/assets/auto_ml/auto_ml.{uuid.uuid4()}/wml_data"
 
         else:
             self.path = path
@@ -576,29 +603,166 @@ class FSLocation(BaseLocation):
         return size
 
 
-class DSLocation(BaseLocation):
+class AssetLocation(BaseLocation):
 
     def __init__(self, asset_id: str) -> None:
-        self.href = f'/v2/assets/{asset_id}?' + '{option}' + '=' + '{id}'
-        self.id = asset_id
+        self._wsd = self._is_wsd()
+
+        if self._wsd:
+            self.href = f'/v2/assets/{asset_id}'
+            self._asset_name = None
+            self._asset_id = None
+            self._local_asset_path = None
+        else:
+            self.href = f'/v2/assets/{asset_id}?' + '{option}' + '=' + '{id}'
+            self.id = asset_id
 
     @classmethod
-    def _set_path(cls, href: str) -> 'DSLocation':
+    def _is_wsd(cls):
+        if os.environ.get('USER_ACCESS_TOKEN'):
+            return False
+
+        try:
+            from project_lib import Project
+            try:
+                access = Project.access()
+                return True
+            except RuntimeError:
+                pass
+        except ModuleNotFoundError:
+            pass
+
+        return False
+
+    @classmethod
+    def _set_path(cls, href: str) -> 'AssetLocation':
         location = cls('.')
         location.href = href
         return location
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
-        verify_request = False if workspace.wml_client.ICP else True
-        asset_info_response = requests.get(workspace.wml_client.data_assets._href_definitions.get_data_asset_href(self.id),
-                                            params= workspace.wml_client._params(),
-                                            headers= workspace.wml_client._get_headers(), verify=verify_request)
+        if self._wsd:
+            return self._wsd_get_file_size()
+        else:
+            verify_request = False if workspace.wml_client.ICP else True
+            asset_info_response = requests.get(workspace.wml_client.data_assets._href_definitions.get_data_asset_href(self.id),
+                                                params= workspace.wml_client._params(),
+                                                headers= workspace.wml_client._get_headers(), verify=verify_request)
+            if asset_info_response.status_code != 200:
+                raise ApiRequestFailure(u"Failure during getting asset details", asset_info_response)
+            return asset_info_response.json()['metadata'].get('size')
+
+    def _wsd_setup_local_asset_details(self) -> None:
+        if not self._wsd:
+            raise NotWSDEnvironment()
+
+        # note: set local asset file from asset_id
+        project = get_project()
+        project_id = project.get_metadata()["metadata"]["guid"]
+
+        local_assets = project.get_files()
+
+        # note: reuse local asset_id when object is reused more times
+        if self._asset_id is None:
+            local_asset_id = self.href.split('/')[3].split('?space_id')[0]
+
+        else:
+            local_asset_id = self._asset_id
+        # --- end note
+
+        if local_asset_id not in str(local_assets):
+            raise MissingLocalAsset(local_asset_id, reason="Provided asset_id cannot be found on WS Desktop.")
+
+        else:
+            for asset in local_assets:
+                if asset['asset_id'] == local_asset_id:
+                    asset_name = asset['name']
+                    self._asset_name = asset_name
+                    self._asset_id = local_asset_id
+
+            local_asset_path = f"{os.path.abspath('.')}/{project_id}/assets/data_asset/{asset_name}"
+            self._local_asset_path = local_asset_path
+
+    def _wsd_move_asset_to_server(self, workspace: 'WorkSpace') -> None:
+        if not self._wsd:
+            raise NotWSDEnvironment()
+
+        if not self._local_asset_path or self._asset_name or self._asset_id:
+            self._wsd_setup_local_asset_details()
+
+        remote_asset_details = workspace.wml_client.data_assets.create(self._asset_name, self._local_asset_path)
+        self.href = remote_asset_details['metadata']['href']
+
+    def _wsd_get_file_size(self) -> 'int':
+        if not self._wsd:
+            raise NotWSDEnvironment()
+
+        if not self._local_asset_path or self._asset_name or self._asset_id:
+            self._wsd_setup_local_asset_details()
+        return os.stat(path=self._local_asset_path).st_size if os.path.isfile(path=self._local_asset_path) else 0
+
+    @classmethod
+    def list_wsd_assets(cls):
+        if not cls._is_wsd():
+            raise NotWSDEnvironment
+
+        project = get_project()
+        return project.get_files()
+
+    def to_dict(self) -> dict:
+        """Return a json dictionary representing this model."""
+        _dict = vars(self).copy()
+
+        del _dict['_wsd']
+
+        if self._wsd:
+            del _dict['_asset_name']
+            del _dict['_asset_id']
+            del _dict['_local_asset_path']
+
+        return _dict
+
+
+class NFSConnection(BaseConnection):
+    """
+    Connection class to file storage in CP4D of NFS format.
+
+    Parameters
+    ----------
+    connection_id: str, required
+        Connection ID from the project on CP4D
+    """
+    def __init__(self, asset_id: str):
+        self.asset_id = asset_id
+
+
+class NFSLocation(BaseLocation):
+    """
+    Location class to file storage in CP4D of NFS format.
+
+    Parameters
+    ----------
+    path: str, required
+        Data path form the project on CP4D.
+    """
+    def __init__(self, path: str):
+        self.path = path
+        self.id = None
+
+    def _get_file_size(self, workspace: 'Workspace', *args) -> 'int':
+        params = workspace.wml_client._params().copy()
+        params['path'] = self.path
+        params['detail'] = 'true'
+
+        href = workspace.wml_client.connections._href_definitions.get_connection_by_id_href(self.id) + '/assets'
+        asset_info_response = requests.get(href,
+                                           params=params, headers=workspace.wml_client._get_headers(None), verify=False)
         if asset_info_response.status_code != 200:
-            raise ApiRequestFailure(u"Failure during getting asset details", asset_info_response)
-        return asset_info_response.json()['metadata'].get('size')
+            raise Exception(u"Failure during getting asset details", asset_info_response.json())['details']['file_size']
+        return asset_info_response.json()['details']['file_size']
 
 
-class CP4DAssetLocation(DSLocation):
+class CP4DAssetLocation(AssetLocation):
     """
     Connection class to data assets in CP4D.
 
@@ -610,12 +774,15 @@ class CP4DAssetLocation(DSLocation):
 
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
+        warning_msg = ("Depreciation Warning: Class CP4DAssetLocation is no longer supported and will be removed."
+                        "Use AssetLocation instead.")
+        print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
-        return super()._get_file_size(workspace, 'project_id', workspace.wml_client.default_project_id)
+        return super()._get_file_size(workspace)
 
 
-class WMLSAssetLocation(DSLocation):
+class WMLSAssetLocation(AssetLocation):
     """
     Connection class to data assets in WML Server.
 
@@ -627,12 +794,15 @@ class WMLSAssetLocation(DSLocation):
 
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
+        warning_msg = ("Depreciation Warning: Class WMLSAssetLocation is no longer supported and will be removed."
+                        "Use AssetLocation instead.")
+        print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
-        return  super()._get_file_size(workspace, 'space_id', workspace.wml_client.default_space_id)
+        return  super()._get_file_size(workspace)
 
 
-class CloudAssetLocation(DSLocation):
+class CloudAssetLocation(AssetLocation):
     """
     Connection class to data assets as input data references to batch deployment job on Cloud.
 
@@ -644,9 +814,12 @@ class CloudAssetLocation(DSLocation):
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
         self.href = self.href
+        warning_msg = ("Depreciation Warning: Class CloudAssetLocation is no longer supported and will be removed."
+                        "Use AssetLocation instead.")
+        print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
-        return super()._get_file_size(workspace, 'space_id', workspace.wml_client.default_space_id)
+        return super()._get_file_size(workspace)
 
 
 class WSDAssetLocation(BaseLocation):
@@ -665,6 +838,10 @@ class WSDAssetLocation(BaseLocation):
         self._asset_id = None
         self._local_asset_path = None
 
+        warning_msg = ("Depreciation Warning: Class WSDAssetLocation is no longer supported and will be removed."
+                       "Use AssetLocation instead.")
+        print(warning_msg)
+
     @classmethod
     def list_assets(cls):
         project = get_project()
