@@ -266,4 +266,18 @@ class ServiceInstance:
             token = response.json().get(u'access_token')
         else:
             raise ApiRequestFailure(u'Error during getting IAM Token.', response)
-        return token
\ No newline at end of file
+        return token
+
+    def _create_zen_token(self):
+        token_url = self._wml_credentials['url'] + '/icp4d-api/v1/authorize'
+        headers = {
+            'Content-type' :'application/json',
+            'cache-control': 'no-cache'
+        }
+        response = requests.post(token_url, auth=(self.get_username(), self.get_password()), verify=False)
+        if response.status_code == 200:
+            print(response)
+            token = response.json().get(u'token')
+        else:
+            raise ApiRequestFailure(u'Error during refreshing ML Token.', response)
+        return token
