@@ -175,8 +175,8 @@ class ServiceInstanceNewPlan:
                 # params = {'version': self._client.version_param}
                 response_get_instance = requests.get(
                     self._href_definitions.get_v4_instance_id_href(),
-                    # params=self._client._params(),
-                    params={'version': self._client.version_param},
+                    params=self._client._params(skip_space_project_chk=True),
+                    # params={'version': self._client.version_param},
                     headers=headers
                 )
 
@@ -195,9 +195,19 @@ class ServiceInstanceNewPlan:
             self._create_token()
             self._client.repository._refresh_repo_client()
         else:
-            if self._get_expiration_datetime() - timedelta(minutes=50) < datetime.now():
-                self._client.wml_token = self._get_IAM_token()
-                self._client.repository._refresh_repo_client()
+            if self._client.ICP:
+                token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
+                response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
+
+                if response.status_code == 200:
+                    token = response.json().get(u'accessToken')
+                else:
+                    raise WMLClientError(u'Error during getting token for the given credentials.', response)
+                return token
+            elif self._client._is_IAM():
+                if self._get_expiration_datetime() - timedelta(minutes=50) < datetime.now():
+                    self._client.wml_token = self._get_IAM_token()
+                    self._client.repository._refresh_repo_client()
             elif self._get_expiration_datetime() - timedelta(minutes=30) < datetime.now():
                 self._client.repository._refresh_repo_client()
                 self._refresh_token()
