@@ -205,7 +205,10 @@ def MLRepositoryArtifact(ml_artifact= None,
                                        name=name, meta_props=meta_props)
 
     if lib_checker.installed_libs[TENSORFLOW]:
-        if isinstance(ml_artifact,tf.Session):
+        import sys
+        if sys.version_info < (3, 7) and \
+                (('2.1.0' in tf.__version__ and isinstance(ml_artifact,tf.compat.v1.Session) or
+                  isinstance(ml_artifact,tf.Session))):
             if signature_def_map is None:
                 raise ValueError("Missing required parameter: signature_def_map")
             elif signature_def_map is  not None:
@@ -218,12 +221,18 @@ def MLRepositoryArtifact(ml_artifact= None,
                                     "type : %s" %(value,meta_graph_pb2.SignatureDef))
 
             if tags is None:
-                tags = [tf.saved_model.tag_constants.SERVING]
+                if '2.1.0' in tf.__version__:
+                    tags = [tf.compat.v1.saved_model.tag_constants.SERVING]
+                else:
+                    tags = [tf.saved_model.tag_constants.SERVING]
             elif tags is not None :
                 if not isinstance(tags,list):
                     raise TypeError("tags should be of type : %s" % list)
-                elif tf.saved_model.tag_constants.SERVING not in tags:
-                    tags.append(tf.saved_model.tag_constants.SERVING)
+                else:
+                    if '2.1.0' in tf.__version__ and tf.compat.v1.saved_model.tag_constants.SERVING not in tags:
+                        tags.append(tf.saved_model.tag_constants.SERVING)
+                    elif tf.saved_model.tag_constants.SERVING not in tags:
+                        tags.append(tf.saved_model.tag_constants.SERVING)
 
             if legacy_init_op is not None:
                 from tensorflow.python.framework import ops
