@@ -93,10 +93,18 @@ class TensorflowVersionHelper(object):
         lib_checker.check_lib(TENSORFLOW)
         class_name = tensorflow_pipeline_model.__class__.__name__
         import tensorflow as tf
-        if isinstance(tensorflow_pipeline_model, tf.Session):
-            return 'tensorflow'
+        if '2.1.0' in tf.__version__ :
+            if isinstance(tensorflow_pipeline_model, tf.compat.v1.Session):
+                return 'tensorflow'
+            else:
+                raise TypeError(
+                    "Expecting object of type : %s" % tf.compat.v1.Session + " but got %s" % type(tensorflow_pipeline_model))
+
         else:
-            raise TypeError("Expecting object of type : %s" % tf.Session + " but got %s" % type(tensorflow_pipeline_model))
+            if isinstance(tensorflow_pipeline_model, tf.Session):
+                return 'tensorflow'
+            else:
+                raise TypeError("Expecting object of type : %s" % tf.Session + " but got %s" % type(tensorflow_pipeline_model))
 
 
 
@@ -104,14 +112,26 @@ class TensorflowVersionHelper(object):
     def model_version(tensorflow_pipeline_model):
         import tensorflow as tf
         class_name = tensorflow_pipeline_model.__class__.__name__
-        if isinstance(tensorflow_pipeline_model,tf.Session):
-            tf_version = tf.__version__
-            if len(tf_version.split('.'))>2:
-                split_tf = tf_version.split('.')
-                tf_version = split_tf[0]+'.' + split_tf[1]
-            return format(tf_version)
+        if '2.1.0' in tf.__version__ :
+            if isinstance(tensorflow_pipeline_model, tf.compat.v1.Session):
+                tf_version = tf.__version__
+                if len(tf_version.split('.')) > 2:
+                    split_tf = tf_version.split('.')
+                    tf_version = split_tf[0] + '.' + split_tf[1]
+                return format(tf_version)
+            else:
+                raise TypeError(
+                    "Expecting object of type : %s" % tf.compat.v1.Session + " but got %s" % type(tensorflow_pipeline_model))
         else:
-            raise TypeError("Expecting object of type : %s" % tf.Session + " but got %s" % type(tensorflow_pipeline_model))
+
+            if isinstance(tensorflow_pipeline_model,tf.Session):
+                tf_version = tf.__version__
+                if len(tf_version.split('.'))>2:
+                    split_tf = tf_version.split('.')
+                    tf_version = split_tf[0]+'.' + split_tf[1]
+                return format(tf_version)
+            else:
+                raise TypeError("Expecting object of type : %s" % tf.Session + " but got %s" % type(tensorflow_pipeline_model))
 
 
 
