@@ -1,12 +1,16 @@
-################################################################################
+# (C) Copyright IBM Corp. 2020.
 #
-# Licensed Materials - Property of IBM
-# (C) Copyright IBM Corp. 2017
-# US Government Users Restricted Rights - Use, duplication disclosure restricted
-# by GSA ADP Schedule Contract with IBM Corp.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-################################################################################
-
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import logging
 import re
@@ -733,7 +737,7 @@ class ModelCollection:
                 if v4_cloud:
                     training_data_ref = {
                         "id": "1",
-                        "type": "s3",
+                        "type": type,
                         "connection": {"endpoint_url": "not_applicable",
                          "access_key_id": "not_applicable",
                          "secret_access_key": "not_applicable"},
