@@ -78,7 +78,8 @@ class LibraryChecker(BaseSingleton):
                     atleast_one_lib_installed = True
                 if 'scikit-learn' == str(pkg):
                     import sklearn
-                    if sklearn.__version__ == '0.23.0':
+                    import sys
+                    if sklearn.__version__ == '0.23.0' and sys.version_info <= (3, 7):
                         raise Exception(' Scikit learn version 0.23.0 is not supported, Please downgrade scikit version to a lower version and re-try. ')
 
             # If above asked package is not found using pip, check if it is installed using 'conda'
