@@ -1,11 +1,16 @@
-################################################################################
+# (C) Copyright IBM Corp. 2020.
 #
-# Licensed Materials - Property of IBM
-# (C) Copyright IBM Corp. 2017
-# US Government Users Restricted Rights - Use, duplication disclosure restricted
-# by GSA ADP Schedule Contract with IBM Corp.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-################################################################################
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from __future__ import print_function
 import requests
@@ -38,7 +43,7 @@ class ModelDefinition(WMLResource):
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _generate_model_definition_document(self, meta_props):
-        if self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             doc = {
                 "metadata":
                 {
@@ -95,13 +100,13 @@ class ModelDefinition(WMLResource):
 
         if self.ConfigurationMetaNames.NAME in meta_props:
             doc["metadata"]["name"] = meta_props[self.ConfigurationMetaNames.NAME]
-            if not self._client.CLOUD_PLATFORM_SPACES:
+            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 # We shouldn't have name and description in entity but this code exists in CP4D
                 # So, changing only for Cloud Convergence
                 doc["entity"]["wml_model_definition"]["name"] = meta_props[self.ConfigurationMetaNames.NAME]
         if self.ConfigurationMetaNames.DESCRIPTION in meta_props:
             doc["metadata"]["description"] = meta_props[self.ConfigurationMetaNames.DESCRIPTION]
-            if not self._client.CLOUD_PLATFORM_SPACES:
+            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 doc["entity"]["wml_model_definition"]["description"] = meta_props[self.ConfigurationMetaNames.DESCRIPTION]
 
         if self.ConfigurationMetaNames.VERSION in meta_props:
@@ -109,14 +114,14 @@ class ModelDefinition(WMLResource):
 
         if self.ConfigurationMetaNames.PLATFORM in meta_props:
             doc["entity"]["wml_model_definition"]["platform"]["name"] = meta_props[self.ConfigurationMetaNames.PLATFORM]['name']
-            if not self._client.CLOUD_PLATFORM_SPACES:
+            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 doc["entity"]["wml_model_definition"]["platform"]["versions"] = \
                     meta_props[self.ConfigurationMetaNames.PLATFORM]['versions']
             else:
                 doc["entity"]["wml_model_definition"]["platform"]["versions"][0] = \
                     meta_props[self.ConfigurationMetaNames.PLATFORM]['versions'][0]
 
-        if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             if self.ConfigurationMetaNames.COMMAND in meta_props:
                 doc['entity']['wml_model_definition'].update({"command": meta_props[self.ConfigurationMetaNames.COMMAND]})
             if self.ConfigurationMetaNames.CUSTOM in meta_props:
@@ -160,7 +165,7 @@ class ModelDefinition(WMLResource):
         model_definition = str_type_conv(model_definition)
         self.ConfigurationMetaNames._validate(meta_props)
 
-        if not self._client.CLOUD_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
 
             # metadata doesn't seem to be used at all.. Code existing pre-convergence.
             # Should be checked sometime and removed if not needed
@@ -289,7 +294,7 @@ class ModelDefinition(WMLResource):
                         if complete_response.status_code == 200:
                             response = self._get_required_element_from_response(model_definition_details)
 
-                            if not self._client.CLOUD_PLATFORM_SPACES:
+                            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                                 return response
                             else:
                                 entity = response[u'entity']
@@ -372,7 +377,7 @@ class ModelDefinition(WMLResource):
             get_model_definition_details = self._handle_response(200, op_name, response_get)
             response = self._get_required_element_from_response(get_model_definition_details)
 
-            if not self._client.CLOUD_PLATFORM_SPACES:
+            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
 
@@ -593,7 +598,7 @@ class ModelDefinition(WMLResource):
                 new_el['metadata'].update({'description': response_data['metadata']['description']})
 
             if 'href' in response_data['metadata']:
-                if self._client.CLOUD_PLATFORM_SPACES:
+                if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                     href_without_host = response_data['href'].split('.com')[-1]
                     new_el[u'metadata'].update({'href': href_without_host})
                 else:
@@ -776,7 +781,7 @@ class ModelDefinition(WMLResource):
         """
 
         # We need to enable this once we add functionality for WSD
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
         ModelDefinition._validate_type(model_definition_id, 'model_definition_id', STR_TYPE, True)
@@ -934,7 +939,7 @@ class ModelDefinition(WMLResource):
 
         response = self._get_required_element_from_response(self._handle_response(200, "Get script details", response))
 
-        if not self._client.CLOUD_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             return response
         else:
             entity = response[u'entity']
@@ -974,7 +979,7 @@ class ModelDefinition(WMLResource):
            >>> model_definition_revision = client.model_definitions.create_revision(model_definition_id)
         """
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 u'Revisions APIs are not supported in this release.')
 
@@ -991,7 +996,7 @@ class ModelDefinition(WMLResource):
         response = self._get_required_element_from_response(
             self._create_revision_artifact_for_assets(model_defn_id, 'Model definition'))
 
-        if not self._client.CLOUD_PLATFORM_SPACES:
+        if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             return response
         else:
             entity = response[u'entity']
@@ -1028,7 +1033,7 @@ class ModelDefinition(WMLResource):
 
         """
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 u'Revisions APIs are not supported in this release.')
         op_name = 'getting model_definition revision details'
@@ -1063,7 +1068,7 @@ class ModelDefinition(WMLResource):
 
             response = self._get_required_element_from_response(self._handle_response(200, op_name, response_get))
 
-            if not self._client.CLOUD_PLATFORM_SPACES:
+            if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
                 entity = response[u'entity']
@@ -1108,7 +1113,7 @@ class ModelDefinition(WMLResource):
 
         """
         ##For CP4D, check if either spce or project ID is set
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES:
+        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 u'Revisions APIs are not supported in this release.')
         self._client._check_if_either_is_set()
