@@ -138,7 +138,7 @@ class Pipelines(WMLResource):
             return doc
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def store(self, meta_props):
+    def store(self, meta_props, **kwargs):
         """
            Create a pipeline.\n
 
@@ -207,14 +207,24 @@ class Pipelines(WMLResource):
                 raise WMLClientError(
                     "It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
+        # add kwargs into optimization section at the very end of preparing payload
+        try:
+            for p in pipeline_meta[self.ConfigurationMetaNames.DOCUMENT]['pipelines']:
+                for n in p['nodes']:
+                    params = n['parameters']['optimization']
+                    params.update(kwargs)
+                    n['parameters']['optimization'] = params
+        except:
+            pass
+
         if not self._ICP and not self._client.WSD:
             if self._client.CLOUD_PLATFORM_SPACES:
-                    creation_response = requests.post(
-                        self._href_definitions.get_pipelines_href(),
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        json=pipeline_meta
-                     )
+                creation_response = requests.post(
+                    self._href_definitions.get_pipelines_href(),
+                    headers=self._client._get_headers(),
+                    params=self._client._params(skip_for_create=True),
+                    json=pipeline_meta
+                 )
             else:
                 creation_response = requests.post(
                     self._wml_credentials['url'] + '/v4/pipelines',
@@ -274,13 +284,13 @@ class Pipelines(WMLResource):
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
 
             elif self._client.ICP_35:
-                    creation_response = requests.post(
-                        self._href_definitions.get_pipelines_href(),
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        json=pipeline_meta,
-                        verify=False
-                     )
+                creation_response = requests.post(
+                    self._href_definitions.get_pipelines_href(),
+                    headers=self._client._get_headers(),
+                    params=self._client._params(skip_for_create=True),
+                    json=pipeline_meta,
+                    verify=False
+                 )
             else:
                 creation_response = requests.post(
                     self._wml_credentials['url'] + '/v4/pipelines',
