@@ -45,7 +45,7 @@ class DataJoinPipeline:
     VisualizationTypes = VisualizationTypes
 
     def __init__(self, preprocessed_data_connection: 'DataConnection', optimizer: 'RemoteAutoPipelines') -> None:
-        self._obm_json = preprocessed_data_connection._download_obm_json_from_cos()
+        self._obm_json = preprocessed_data_connection._download_obm_json()
         self._pipeline_json = self._obm_json['Pipeline']
         self._obm_pipeline_graph_builder = OBMPipelineGraphBuilder(self._obm_json)
         self._graph_json, self._graph = self._obm_pipeline_graph_builder.build_graph()
@@ -271,7 +271,7 @@ class OBMPipelineGraphBuilder:
         join_path = feature_info_json.get("join_path")
         results = {}
         results['tables'] = join_path.get("tables")
-        results['columns'] = join_path.get("columns")
+        results['join_keys'] = join_path.get("join_keys")
         results['feature_name'] = feature_info_json.get("feature_name")
         results['op'] = feature_info_json.get("expression", {}).get("op")
         results['params'] = feature_info_json.get("expression", {}).get("params")
@@ -330,6 +330,7 @@ class OBMPipelineGraphBuilder:
                                       normalized_count, normalized_sum, trend, recent_gap_to_cutoff,
                                       max_gap_to_cutoff, string_indexer)
         from lale.lib.lale import Scan, Join, Map, GroupBy, Aggregate, ConcatFeatures, Project, Relational
+        from lale.operators import make_pipeline_graph
 
         transformation_to_func_map = {"max": max, "count": count, "sum": sum, "day_of_month": day_of_month,
                                       "day_of_week": day_of_week, "day_of_year": day_of_year, "month": month,
@@ -352,12 +353,12 @@ class OBMPipelineGraphBuilder:
                                    "window_min_trend", "window_variance", "window_variance_trend",
                                    "recent_gap_to_cutoff"]
         time_cufoff_functions = ["max_gap_to_cutoff", "recent_gap_to_cutoff"]
-        extractors_list = []
+        level_3_nodes_list = []
         joins = {}
         for msg in self.trained_pipeline_json.get("feature_engineering_components")[0].get("obm"):
             feature_info = self.get_feature_info(msg)
             join_tables = feature_info["tables"]
-            join_keys = feature_info["columns"]
+            join_keys = feature_info["join_keys"]
             feature_name = feature_info["feature_name"]
             op = feature_info["op"]
             column = feature_info["params"]
@@ -372,6 +373,10 @@ class OBMPipelineGraphBuilder:
             feature_list.append(
                 (feature_name, op, column, pattern, timestamp_condition, join_limit, sliding_window_length))
             joins[join_tables_str] = (join_tables, join_keys, feature_list)
+        scan_tables_already_added = {}
+        #The pipeline graph needs to be built level-wise, so keep track of steps and edges.
+        pipeline_steps = []
+        pipeline_edges = []
         for join_tables_str, join_info in joins.items():
             scan_table_nodes = []
             join_keys_idx = 0
@@ -383,8 +388,12 @@ class OBMPipelineGraphBuilder:
                 elem1 = feature_list[0]
                 feature_name, op, column, pattern, timestamp_condition, join_limit, sliding_window_length = elem1
             for table_idx, table in enumerate(join_tables):
-                scan_table_node = Scan(
-                    table=Expr(ast.Subscript(value=ast.Name('it', ast.Store()), slice=ast.Index(ast.Str(s=table)))))
+                scan_table_node = scan_tables_already_added.get(table, None)
+                if table not in scan_tables_already_added:
+                    scan_table_node = Scan(
+                        table=Expr(ast.Subscript(value=ast.Name('it', ast.Store()), slice=ast.Index(ast.Str(s=table)))))
+                    pipeline_steps.append(scan_table_node)
+                    scan_tables_already_added[table] = scan_table_node
                 scan_table_nodes.append(scan_table_node)
                 # create a join predicate for this table and next if this is not the last table
                 if table_idx != len(join_tables) - 1:
@@ -415,16 +424,15 @@ class OBMPipelineGraphBuilder:
                     slice=ast.Index(ast.Str(s=timestamp_condition[3])))
                 predicates_list.append(Expr(ast.Compare(left=lhs, ops=[ast.GtE()], comparators=[rhs])))
 
-            scan_conjunction = scan_table_nodes[0]
-            for i in range(1, len(scan_table_nodes)):
-                scan_conjunction = scan_conjunction & scan_table_nodes[i]
             # Assuming each extractor covers only one join
             if len(predicates_list) > 0:
                 join_node = Join(pred=predicates_list, join_limit=join_limit,
                                  sliding_window_length=sliding_window_length)
-                join_prefix = (scan_conjunction) >> join_node
+                pipeline_steps.append(join_node)
+                for i in range(0, len(scan_table_nodes)):
+                    pipeline_edges.append((scan_table_nodes[i], join_node))
             else:
-                join_prefix = scan_conjunction
+                join_node = None
 
             aggregate_transformations = {}
             map_transformations = {}
@@ -498,25 +506,33 @@ class OBMPipelineGraphBuilder:
                         for column_name in self.group_by_key]
                 ops_list.append(Aggregate(columns=aggregate_transformations, group_by=group_by_expr))
             if len(ops_list) > 0:
-                extractors_conjunction = ops_list[0]
-                for i in range(1, len(ops_list)):
-                    extractors_conjunction = extractors_conjunction & ops_list[i]
-                extractors_prefix = join_prefix >> (extractors_conjunction)
-                extractors_list.append(extractors_prefix)
+                for i in range(0, len(ops_list)):
+                    pipeline_steps.append(ops_list[i])
+                    if join_node is not None:
+                        pipeline_edges.append((join_node, ops_list[i]))
+                    else:
+                        for i in range(0, len(scan_table_nodes)):
+                            pipeline_edges.append((scan_table_nodes[i], ops_list[i]))
+                level_3_nodes_list.extend(ops_list)
+            elif join_node is not None: #if ops_list is empty, the nodes from the last level in the graph are either scan or join
+                level_3_nodes_list.append(join_node)
+            else:
+                level_3_nodes_list.extend(scan_table_nodes)
         # Use ConcatFeatures on the extractors_prefix and then selectFeatures
-        feature_extractors_conjunction = extractors_list[0]
-        for i in range(1, len(extractors_list)):
-            feature_extractors_conjunction = feature_extractors_conjunction & extractors_list[i]
-        all_features = feature_extractors_conjunction >> ConcatFeatures()
+        concat = ConcatFeatures()
+        pipeline_steps.append(concat)
+        for i in range(0, len(level_3_nodes_list)):
+            pipeline_edges.append((level_3_nodes_list[i], concat))
+
         # Add the component that converts categorical columns to numerical using a string indexer.
         if self.categorical_column_names is not None:
             string_indexer_encoding = Map(columns=[
                 string_indexer(
                     ast.Subscript(value=ast.Name('it', ast.Store()), slice=ast.Index(ast.Str(s=categorical_column))))
                 for categorical_column in self.categorical_column_names], remainder="passthrough")
-            nested_pipeline = all_features >> string_indexer_encoding
-        else:
-            nested_pipeline = all_features
+            pipeline_steps.append(string_indexer_encoding)
+            pipeline_edges.append((concat, string_indexer_encoding))
+        nested_pipeline = make_pipeline_graph(pipeline_steps, pipeline_edges)
         return Relational(operator=nested_pipeline)
 
     def build_graph(self) -> Tuple[dict, 'Digraph']:
