@@ -509,7 +509,7 @@ class Repository(WMLResource):
 
             .. important::
                 #. **meta_props**:  meta data or name of the function. To see available meta names use:\n
-                                    >>> client.functions.ConfigurationMetaNames.get()
+                                    >>> client.repository.FunctionMetaNames.show()
 
                        **type**: dict\n
                 #. **function**:  path to file with archived function content or function (as described above)\n
@@ -530,10 +530,15 @@ class Repository(WMLResource):
 
              The most simple use is (using `score` function):
 
+             >>> meta_props = {
+             >>>    client.repository.FunctionMetaNames.NAME: "function",
+             >>>    client.repository.FunctionMetaNames.DESCRIPTION: "This is ai function",
+             >>>    client.repository.FunctionMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
+
              >>> def score(payload):
              >>>      values = [[row[0]*row[1]] for row in payload['values']]
              >>>      return {'fields': ['multiplication'], 'values': values}
-             >>> stored_function_details = client.functions.store(score, name)
+             >>> stored_function_details = client.repository.store_function(score, meta_props)
 
              Other, more interesting example is using generator function.
              In this situation it is possible to pass some variables:
@@ -544,19 +549,7 @@ class Repository(WMLResource):
                             values = [[row[0]*row[1]*x] for row in payload['values']]
                             return {'fields': ['multiplication'], 'values': values}
                         return f
-                >>> stored_function_details = client.functions.store(gen_function, name)
-
-             In more complicated cases you should create proper metadata, similar to this one:
-
-                >>> metadata = {
-                >>>    client.repository.FunctionMetaNames.NAME: "function",
-                >>>    client.repository.FunctionMetaNames.DESCRIPTION: "This is ai function",
-                >>>    client.repository.FunctionMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f",
-                >>>    client.repository.FunctionMetaNames.INPUT_DATA_SCHEMAS: [{"fields": [{"metadata": {}, "type": "string", "name": "GENDER", "nullable": True}]}],
-                >>>    client.repository.FunctionMetaNames.OUTPUT_DATA_SCHEMAS:[{"fields": [{"metadata": {}, "type": "string", "name": "GENDER", "nullable": True}]}],
-                >>>    client.repository.FunctionMetaNames.TAGS: [{"value": "ProjectA", "description": "Functions created for ProjectA"}]
-                >>> }
-                >>> stored_function_details = client.repository.store_function(score, metadata)
+                >>> stored_function_details = client.repository.store_function(gen_function, meta_props)
             """
 
         return self._client._functions.store(function, meta_props)
@@ -834,7 +827,7 @@ class Repository(WMLResource):
             >>> model_obj = client.repository.load(model_uid)
         """
 
-        return self._client._models.load(self,artifact_uid)
+        return self._client._models.load(artifact_uid)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, artifact_uid, filename='downloaded_artifact.tar.gz', rev_uid=None, format=None):
