@@ -200,7 +200,8 @@ class Script(WMLResource):
         elif extension == '.R':
             lang = 'R'
         else:
-            lang = 'python3'
+            raise WMLClientError("This file type is not supported. It has to be either a python script(.py file ) or a "
+                                 "R script")
 
         #check if the software spec specified is base or derived and
         # accordingly update the entity for asset creation
@@ -210,6 +211,14 @@ class Script(WMLResource):
         if not self._client.WSD:
             sw_spec_details = self._client.software_specifications.get_details(script_meta[u'software_spec_uid'])
 
+            if lang == 'R':
+                rscript_sw_spec_id = self._client.software_specifications.get_id_by_name('default_r3.6')
+
+                if rscript_sw_spec_id != script_meta[u'software_spec_uid']:
+                    raise WMLClientError("For R scripts, only base software spec 'default_r3.6' is supported. Specify "
+                                         "the id you get via "
+                                         "self._client.software_specifications.get_id_by_name('default_r3.6')")
+
             if(sw_spec_details[u'entity'][u'software_specification'][u'type'] == 'base'):
                 if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                     asset_meta = {
@@ -905,12 +914,12 @@ class Script(WMLResource):
 
         """
         Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
+                self._if_deployment_exist_for_asset(asset_uid):
+            raise WMLClientError(
+                u'Cannot delete script that has existing deployments. Please delete all associated deployments and try again')
 
         if not self._ICP:
-            if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and self._if_deployment_exist_for_asset(asset_uid):
-                raise WMLClientError(
-                    u'Cannot delete script that has existing deployments. Please delete all associated deployments and try again')
-
             response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
