@@ -733,6 +733,10 @@ class Shiny(WMLResource):
 
         """
         Shiny._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
+                self._if_deployment_exist_for_asset(asset_uid):
+            raise WMLClientError(
+                u'Cannot delete shiny asset that has existing deployments. Please delete all associated deployments and try again')
 
         if not self._ICP:
             response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
