@@ -263,7 +263,7 @@ class TestAutoAIRemote(unittest.TestCase):
         runs_completed_df = runs_df[runs_df.state == 'completed']
 
         from random import randint
-        TestAutoAIRemote.random_run_id = runs_completed_df.run_id[
+        TestAutoAIRemote.random_run_id = runs_completed_df.run_id.iloc[
             randint(len(runs_completed_df) // 2,
                     len(runs_completed_df) - 1)]  # random run_id from the 2nd part of runs table
         print("Random run_id from 2nd half of df: {}".format(TestAutoAIRemote.random_run_id))
