@@ -9,7 +9,7 @@ from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, DSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, AssetLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
@@ -101,7 +101,7 @@ class TestAutoAIRemote(unittest.TestCase):
             asset_id = asset_details['metadata']['guid']
 
             TestAutoAIRemote.data_connection = DataConnection(
-                location=DSLocation(asset_id=asset_id))
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else:  # for cloud and COS
