@@ -10,9 +10,10 @@ from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, WMLSAssetLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, AssetLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
+from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit
 
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, bucket_name_gen, get_space_id
@@ -55,7 +56,7 @@ class TestAutoAIRemote(unittest.TestCase):
     run_id = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     data_connection = None
     results_connection = None
@@ -87,7 +88,7 @@ class TestAutoAIRemote(unittest.TestCase):
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -112,8 +113,11 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP:
@@ -158,7 +162,7 @@ class TestAutoAIRemote(unittest.TestCase):
             asset_id = asset_details['metadata']['guid']
 
             TestAutoAIRemote.data_connection = DataConnection(
-                location=WMLSAssetLocation(asset_id=asset_id))
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -181,15 +185,22 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
 
     def test_02a_read_saved_remote_data_before_fit(self):
-        data = self.data_connection.read(excel_sheet=self.sheet_name)
-        print(f"Data sample, excel_sheet ={self.sheet_name}:")
-        print(data.head())
-        self.assertGreater(len(data), 0)
+        if self.wml_client.ICP:
+            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
+                data = self.data_connection.read(excel_sheet=self.sheet_name)
 
-        data = self.data_connection.read(excel_sheet=self.sheet_number)
-        print(f"Data sample, excel_sheet ={self.sheet_number}:")
-        print(data.head())
-        self.assertGreater(len(data), 0)
+            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
+                data = self.data_connection.read(excel_sheet=self.sheet_number)
+        else:
+            data = self.data_connection.read(excel_sheet=self.sheet_name)
+            print(f"Data sample, excel_sheet ={self.sheet_name}:")
+            print(data.head())
+            self.assertGreater(len(data), 0)
+
+            data = self.data_connection.read(excel_sheet=self.sheet_number)
+            print(f"Data sample, excel_sheet ={self.sheet_number}:")
+            print(data.head())
+            self.assertGreater(len(data), 0)
 
     def test_03_initialize_optimizer(self):
         TestAutoAIRemote.remote_auto_pipelines = self.experiment.optimizer(
@@ -202,7 +213,7 @@ class TestAutoAIRemote(unittest.TestCase):
             test_size=0.1,
             max_number_of_estimators=1,
             excel_sheet=self.sheet_name,
-            # autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version
 
         )
 
@@ -377,7 +388,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_22__deploy__online_deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model=self.pipeline,
+            model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
@@ -401,6 +412,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_25_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 if __name__ == '__main__':
     unittest.main()
