@@ -15,11 +15,13 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
+from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
+
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
                                                         bucket_name_gen, get_space_id, is_cp4d)
 from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
 
-from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize
+from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
 from lale import wrap_imported_operators
@@ -62,7 +64,7 @@ class TestAutoAIRemote(unittest.TestCase):
     train_data = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     data_cos_path = 'data/breast_cancer.csv'
@@ -90,11 +92,10 @@ class TestAutoAIRemote(unittest.TestCase):
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
-
         cls.wml_credentials = get_wml_credentials()
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
@@ -113,8 +114,10 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
 
     def test_00b_prepare_COS_instance(self):
@@ -153,11 +156,6 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
-            if self.project_id: #if CPD
-                self.wml_client.set.default_project(self.project_id)
-            else:  #if WMLS
-                self.wml_client.set.default_space(self.space_id)
-
             TestAutoAIRemote.data_connection = DataConnection(
                             location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
@@ -195,6 +193,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             positive_label=self.positive_label,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
+            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
+                                     Transformers.SIN,Transformers.SUM],
             test_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L
@@ -219,6 +219,37 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
 
+    def test_05a_fit_error_when_cos_file_not_exists(self):
+        if self.wml_client.ICP:
+            self.skipTest("Prepare COS is available only for Cloud")
+
+        with self.assertRaises(NotExistingCOSResource, msg="Training should raise error when non existing COS bucket given"):
+            self.remote_auto_pipelines.fit(
+                training_data_reference=[
+                    DataConnection(
+                    connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                            access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                            secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                    location=S3Location(bucket="not_existing",
+                                        path=self.data_cos_path)
+                )],
+                training_results_reference=self.results_connection,
+                background_mode=False)
+
+        with self.assertRaises(NotExistingCOSResource, msg="Training should raise error when non existing COS file given"):
+            self.remote_auto_pipelines.fit(
+                training_data_reference=[
+                    DataConnection(
+                        connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                                secret_access_key=self.cos_credentials['cos_hmac_keys'][
+                                                    'secret_access_key']),
+                        location=S3Location(bucket=self.bucket_name,
+                                            path="not_existing")
+                    )],
+                training_results_reference=self.results_connection,
+                background_mode=False)
+
     def test_06_get_train_data(self):
         TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
 
@@ -320,7 +351,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_22__deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model=self.pipeline,
+            model="Pipeline_1",
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
@@ -344,6 +375,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_25_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(self.service.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(self.service.scoring_url, None,
@@ -354,8 +388,14 @@ class TestAutoAIRemote(unittest.TestCase):
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                               source_space_id=self.space_id)
+        if self.wml_client.ICP:
+            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                                   source_project_id=self.project_id,
+                                                   target_wml_credentials=self.wml_credentials,
+                                                   target_space_id=self.space_id)
+        else:
+            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
+                                                   source_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
@@ -365,7 +405,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_32__deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service_batch.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model=self.pipeline,
+            model="Pipeline_2",
             deployment_name=self.DEPLOYMENT_NAME + ' BATCH')
 
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
@@ -392,8 +432,11 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(params)
 
     def test_35_delete_deployment_batch(self):
-        print("Delete current deployment: {}".format(self.service.deployment_id))
+        print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service_batch.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(self.service_batch.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(self.service_batch.scoring_url, None,
