@@ -11,8 +11,8 @@ import pprint
 
 from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, WMLSAssetLocation,\
-    CloudAssetLocation, FSLocation, DeploymentOutputAssetLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation,\
+    AssetLocation, DeploymentOutputAssetLocation
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 from ibm_watson_machine_learning.deployment import WebService, Batch
 from ibm_watson_machine_learning.workspace import WorkSpace
@@ -61,7 +61,7 @@ class TestAutoAIRemote(unittest.TestCase):
     new_pipeline = None
     new_sklearn_pipeline = None
 
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     data_connection = None
     results_connection = None
@@ -92,7 +92,7 @@ class TestAutoAIRemote(unittest.TestCase):
     
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -119,8 +119,10 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP or self.wml_client.WSD:
@@ -158,13 +160,8 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
-            asset_details = self.wml_client.data_assets.create(
-                name=self.data_location.split('/')[-1],
-                file_path=self.data_location)
-            asset_id = asset_details['metadata']['guid']
-
             TestAutoAIRemote.data_connection = DataConnection(
-                                location=WMLSAssetLocation(asset_id=asset_id))
+                                location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -198,7 +195,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column='price',
             scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            # autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -309,9 +306,9 @@ class TestAutoAIRemote(unittest.TestCase):
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
 
-    def test_21_deploy_pipepline_lale_type(self):
+    def test_21_deploy_pipepline_by_name(self):
         TestAutoAIRemote.service.create(
-            model=self.lale_pipeline,
+            model="Pipeline_4",
             deployment_name=self.DEPLOYMENT_NAME,
             experiment_run_id=self.run_id
         )
@@ -336,24 +333,33 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_24_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
     #########################
     #  Batch deployment
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                               source_space_id=self.space_id)
+        if self.wml_client.ICP:
+            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                                   source_project_id=self.project_id,
+                                                   target_wml_credentials=self.wml_credentials,
+                                                   target_space_id=self.space_id)
+        else:
+            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
+                                                   source_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID initialized incorrectly")
         self.assertEqual(self.service_batch.name, None, msg="Deployment name initialized incorrectly")
 
-    def test_32__deploy__batch_deploy_blale_pipeline_from_autoai_on_wml(self):
+    def test_32__deploy__batch_deploy_pipeline_from_autoai_on_wml(self):
         self.service_batch.create(
             experiment_run_id=self.run_id,
-            model=self.lale_pipeline,
+            model="Pipeline_1",
             deployment_name=self.DEPLOYMENT_NAME+' BATCH')
 
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
@@ -362,28 +368,16 @@ class TestAutoAIRemote(unittest.TestCase):
                           msg="Batch Deployment creation - model (asset) id missing, incorrect model storing")
 
     def test_33a_run_job_batch_deployed_model_with_data_connection_data_asset(self):
-        self.wml_client.set.default_space(space_uid=self.space_id)
+        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
+
         asset_details = self.wml_client.data_assets.create(
             name=self.batch_payload_location.split('/')[-1],
             file_path=self.batch_payload_location)
         asset_id = asset_details['metadata']['guid']
         asset_href = self.wml_client.data_assets.get_href(asset_details)
 
-        if self.wml_client.ICP:
-            payload_reference = DataConnection(location=WMLSAssetLocation(asset_id=asset_id))
-        else:
-            payload_reference = DataConnection(location=CloudAssetLocation(asset_id=asset_id))
-            # {
-            #             "name": "car_price_payload.csv",
-            #             "type": "data_asset",
-            #             "connection": {
-            #
-            #             },
-            #             "location": {
-            #               "id": asset_id,
-            #                 "href": asset_href
-            #             }
-            #             }
+        payload_reference = DataConnection(location=AssetLocation(asset_id=asset_id))
+
         results_reference = DataConnection(
             location=DeploymentOutputAssetLocation(name="batch_output_car-price.csv"))
 
@@ -391,6 +385,9 @@ class TestAutoAIRemote(unittest.TestCase):
             payload=[payload_reference],
             output_data_reference=results_reference,
             background_mode=False)
+
+        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+
         print(scoring_params)
         self.assertIsNotNone(scoring_params)
         self.wml_client.data_assets.list()
@@ -433,6 +430,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_35_delete_deployment_batch(self):
         print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service_batch.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(self.service_batch.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(self.service_batch.scoring_url, None,
