@@ -17,9 +17,9 @@ from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, WMLSAssetLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
 
-from ibm_watson_machine_learning.tests.utils.utils import get_wml_credentials, get_cos_credentials, bucket_exists, bucket_name_gen, get_space_id
+from ibm_watson_machine_learning.tests.utils.utils import get_wml_credentials, get_cos_credentials, bucket_exists, bucket_name_gen, get_space_id, is_cp4d
 from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize
 
@@ -63,7 +63,7 @@ class TestAutoAIRemote(unittest.TestCase):
     else:
         bucket_name = "wml-autoaitests-qa"
 
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     data_cos_path = 'data/credit_risk_training_light.csv'
     cos_resource_instance_id = None
@@ -84,7 +84,7 @@ class TestAutoAIRemote(unittest.TestCase):
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -112,8 +112,11 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP or self.wml_client.WSD:
@@ -152,18 +155,8 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
-            if self.project_id: #if CPD
-                self.wml_client.set.default_project(self.project_id)
-            else:  #if WMLS
-                self.wml_client.set.default_space(self.space_id)
-            asset_details = self.wml_client.data_assets.create(
-                name=self.data_location.split('/')[-1],
-                file_path=self.data_location)
-            asset_id = asset_details['metadata']['guid']
-
-            #TODO CP4D Location
             TestAutoAIRemote.data_connection = DataConnection(
-                                location=WMLSAssetLocation(asset_id=asset_id))
+                                location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -206,7 +199,7 @@ class TestAutoAIRemote(unittest.TestCase):
             # positive_label='Risk',
             scoring=AutoAI.Metrics.ACCURACY_SCORE,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            # autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -333,7 +326,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_22__deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service.create(
             experiment_run_id=self.run_id,
-            model=self.new_pipeline,
+            model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.name)
@@ -350,6 +343,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_25_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 if __name__ == '__main__':
     unittest.main()
