@@ -10,7 +10,7 @@ import pprint
 
 from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, WMLSAssetLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 from ibm_watson_machine_learning.deployment import WebService
 
@@ -64,7 +64,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     # CLOUD CONNECTION DETAILS:
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     data_cos_path = 'data/credit_risk_insurance__two_sheets.xlsx'
@@ -84,7 +84,7 @@ class TestAutoAIRemote(unittest.TestCase):
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -97,10 +97,6 @@ class TestAutoAIRemote(unittest.TestCase):
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
             cls.cos_resource_instance_id = cls.cos_credentials.get('resource_instance_id')
-        else:
-            # note: xlsx is not supported on WMLS
-            cls.data_location = './autoai/data/CarPrice_Assignment.csv'
-            # --- end note
 
         cls.project_id = cls.wml_credentials.get('project_id')
 
@@ -111,8 +107,11 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+
+        if TestAutoAIRemote.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP or self.wml_client.WSD:
@@ -151,17 +150,8 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
-            if self.project_id:  # if CPD
-                self.wml_client.set.default_project(self.project_id)
-            else:  # if WMLS
-                self.wml_client.set.default_space(self.space_id)
-            asset_details = self.wml_client.data_assets.create(
-                name=self.data_location.split('/')[-1],
-                file_path=self.data_location)
-            asset_id = asset_details['metadata']['guid']
-
             TestAutoAIRemote.data_connection = DataConnection(
-                location=WMLSAssetLocation(asset_id=asset_id))
+                location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
 
         else:  # for cloud and COS
@@ -206,7 +196,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.target_column,
             scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
             excel_sheet=self.sheet_number, #insurance data are located in second sheet named 'insurance'
-            # autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -338,6 +328,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_24_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 
 if __name__ == '__main__':
