@@ -27,6 +27,7 @@ class TestAutoAIRemote(unittest.TestCase):
     - COS set-up (if run on Cloud): checking if bucket exists for the cos instance, if not new bucket is create
     - Saving data `datasets_different_delimeter/iris_dataset_different_delimeter.csv` to COS/data assets
     - multiclass experiment for datasets with different delimeter dataset and `;` separator
+    - experiment is run on PROJECT (CPD and CLOUD)
     - downloading all generated pipelines to lale pipeline
     - list historical runs
     - get one historical run and download its pipeline
@@ -68,7 +69,7 @@ class TestAutoAIRemote(unittest.TestCase):
     cos_resource_instance_id = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
-    # pod_version = environ.get('KB_VERSION', None)
+    pod_version = environ.get('KB_VERSION', None)
 
     data_cos_path = 'data/iris_dataset_different_delimeter.csv'
 
@@ -80,12 +81,12 @@ class TestAutoAIRemote(unittest.TestCase):
     DEPLOYMENT_NAME = "Iris AutoAI Deployment tests"
 
     project_id = None
-    space_id = 'e1c2698f-d5fb-48b0-a62d-3261180898cb'
+    space_id = None
 
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -113,8 +114,11 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=2)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                                  cos_resource_instance_id=self.cos_resource_instance_id)
-        TestAutoAIRemote.project_id = None
-        TestAutoAIRemote.wml_client.set.default_space(TestAutoAIRemote.space_id)
+
+        # if self.wml_client.ICP:
+        self.wml_client.set.default_project(self.project_id)
+        # else:
+        #     self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP or self.wml_client.WSD:
@@ -144,13 +148,8 @@ class TestAutoAIRemote(unittest.TestCase):
         print(f"Using COS bucket: {TestAutoAIRemote.bucket_name}")
 
     def test_01_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                                 project_id=self.project_id,
-                                                 space_id=self.space_id)
-        else:
-            TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials,
-                                                 space_id=self.space_id)
+        TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                             project_id=self.project_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -159,7 +158,6 @@ class TestAutoAIRemote(unittest.TestCase):
             TestAutoAIRemote.data_connection = DataConnection(
                                 location=FSLocation(path=self.data_location))
             TestAutoAIRemote.results_connection = None
-
         else: #for cloud and COS
             TestAutoAIRemote.data_connection = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
@@ -201,7 +199,7 @@ class TestAutoAIRemote(unittest.TestCase):
             max_number_of_estimators=1,
             csv_separator=self.custom_separator,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            # autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -323,15 +321,12 @@ class TestAutoAIRemote(unittest.TestCase):
         runs_completed_df = runs_df[runs_df.state =='completed']
 
         from random import randint
-        TestAutoAIRemote.random_run_id = runs_completed_df.run_id[
+        TestAutoAIRemote.random_run_id = runs_completed_df.run_id.iloc[
             randint(len(runs_completed_df) // 2, len(runs_completed_df) - 1)]  # random run_id from the 2nd part of runs table
         print("Random run_id from 2nd half of df: {}".format(TestAutoAIRemote.random_run_id))
         self.assertIsNotNone(TestAutoAIRemote.random_run_id)
 
     def test_16_get_params_of_last_historical_run(self):
-        # TestAutoAIRemote.run_id = 'c6823125-aed1-4bd6-bd06-102930c3daa5'
-        # TestAutoAIRemote.random_run_id = 'c6823125-aed1-4bd6-bd06-102930c3daa5'
-
         run_params = self.experiment.runs.get_params(run_id=self.run_id)
         self.assertIn('prediction_type', run_params,
                       msg="prediction_type field not fount in run_params. Run_params are: {}".format(run_params))
@@ -376,18 +371,16 @@ class TestAutoAIRemote(unittest.TestCase):
     #################################
 
     def test_20_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                                  source_project_id=self.project_id,
-                                                  source_space_id=self.space_id)
-            self.wml_client.set.default_space(self.space_id)
-        else:
-            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials,
-                                                  source_space_id=self.space_id)
+        self.wml_client.set.default_space(self.space_id)
+
+        TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+                                              source_project_id=self.project_id,
+                                              target_wml_credentials=self.wml_credentials.copy(),
+                                              target_space_id=self.space_id)
 
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_project(self.project_id)
 
     def test_21_deploy_pipepline_by_pipeline_name(self):
         TestAutoAIRemote.service.create(
@@ -416,27 +409,22 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_24_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id)
 
     def test_25_deployment_setup_and_preparation_different_wml(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                                  source_project_id=self.project_id,
-                                                  source_space_id=self.space_id,
-                                                  target_wml_credentials=self.wml_credentials.copy(),
-                                                  target_project_id=self.project_id,
-                                                  target_space_id=self.space_id
-                                                  )
-            self.wml_client.set.default_space(self.space_id)
-        else:
-            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials,
-                                                  source_space_id=self.space_id,
-                                                  target_wml_credentials=self.wml_credentials,
-                                                  target_space_id=self.space_id,
-                                                  )
+        self.wml_client.set.default_space(self.space_id)
+
+        TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+                                              source_project_id=self.project_id,
+                                              target_wml_credentials=self.wml_credentials.copy(),
+                                              target_space_id=self.space_id
+                                              )
 
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_project(self.project_id)
 
     def test_26_deploy_pipepline_by_pipeline_name_different_wml(self):
         TestAutoAIRemote.service.create(
@@ -461,20 +449,19 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_29_delete_deployment_different_wml(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id)
 
     #########################
     #  Batch deployment
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
-                                                   target_wml_credentials=self.wml_credentials,
-                                                   target_space_id=self.space_id)
-        else:
-            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                                   source_space_id=self.space_id)
+        TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                               source_project_id=self.project_id,
+                                               target_wml_credentials=self.wml_credentials,
+                                               target_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
@@ -484,7 +471,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_32__deploy__batch_deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service_batch.create(
             experiment_run_id=self.run_id,
-            model=self.lale_pipeline,
+            model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME+'BATCH')
 
         self.assertIsNotNone(self.service_batch.id, msg="Batch Deployment creation - missing id")
@@ -506,8 +493,11 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(params)
 
     def test_35_delete_deployment_batch(self):
-        print("Delete current deployment: {}".format(self.service.deployment_id))
+        print("Delete current deployment: {}".format(self.service_batch.deployment_id))
         self.service_batch.delete()
+        self.wml_client.set.default_space(self.space_id)
+        self.wml_client.repository.delete(self.service_batch.asset_id)
+        self.wml_client.set.default_project(self.project_id)
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(self.service_batch.name, None, msg="Deployment name deleted incorrectly")
         self.assertEqual(self.service_batch.scoring_url, None,
