@@ -12,17 +12,17 @@ from ibm_watson_machine_learning.deployment import Batch
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
-from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
+from ibm_watson_machine_learning.tests.utils import bucket_exists, \
     bucket_name_gen, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
 
 from ibm_watson_machine_learning.tests.utils import (
-    get_wml_credentials, get_cos_credentials, is_cp4d, get_env, print_test_separators)
+    get_wml_credentials, get_cos_credentials, is_cp4d, print_test_separators)
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
 
 get_step_details = OBMPipelineGraphBuilder.get_step_details
@@ -61,6 +61,7 @@ class TestOBMOnly(unittest.TestCase):
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
 
     cos_endpoint =  "https://s3.us-south.cloud-object-storage.appdomain.cloud"
+    cos_resource_instance_id = None
     data_cos_path = 'data/'
 
     results_cos_path = 'results_wml_autoai'
@@ -88,10 +89,11 @@ class TestOBMOnly(unittest.TestCase):
     #     space_id = None
 
     project_id = None
+    space_id = None
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -113,8 +115,11 @@ class TestOBMOnly(unittest.TestCase):
                       days_old=2)
         TestOBMOnly.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestOBMOnly.project_id = None
-        TestOBMOnly.wml_client.set.default_space(TestOBMOnly.space_id)
+
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -148,50 +153,81 @@ class TestOBMOnly(unittest.TestCase):
     @print_test_separators
     def test_01_create_multiple_data_connections__connections_created(self):
         print("Creating multiple data connections...")
-        TestOBMOnly.main_conn = DataConnection(
-            data_join_node_name="main",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_main.csv'))
+        if self.wml_client.ICP:
+            TestOBMOnly.main_conn = DataConnection(
+                data_join_node_name="main",
+                location=FSLocation(path=self.data_location + 'group_customer_main.csv'))
 
-        TestOBMOnly.customers_conn = DataConnection(
-            data_join_node_name="customers",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_customers.csv'))
+            TestOBMOnly.customers_conn = DataConnection(
+                data_join_node_name="customers",
+                location=FSLocation(path=self.data_location + 'group_customer_customers.csv'))
 
-        TestOBMOnly.transactions_conn = DataConnection(
-            data_join_node_name="transactions",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_transactions.csv'))
+            TestOBMOnly.transactions_conn = DataConnection(
+                data_join_node_name="transactions",
+                location=FSLocation(path=self.data_location + 'group_customer_transactions.csv'))
 
-        TestOBMOnly.purchases_conn = DataConnection(
-            data_join_node_name="purchases",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_purchase.csv'))
+            TestOBMOnly.purchases_conn = DataConnection(
+                data_join_node_name="purchases",
+                location=FSLocation(path=self.data_location + 'group_customer_purchase.csv'))
 
-        TestOBMOnly.products_conn = DataConnection(
-            data_join_node_name="products",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_products.csv'))
+            TestOBMOnly.products_conn = DataConnection(
+                data_join_node_name="products",
+                location=FSLocation(path=self.data_location + 'group_customer_products.csv'))
+
+            TestOBMOnly.results_connection = None
+        else:
+            TestOBMOnly.main_conn = DataConnection(
+                data_join_node_name="main",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_main.csv'))
+
+            TestOBMOnly.customers_conn = DataConnection(
+                data_join_node_name="customers",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_customers.csv'))
+
+            TestOBMOnly.transactions_conn = DataConnection(
+                data_join_node_name="transactions",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_transactions.csv'))
+
+            TestOBMOnly.purchases_conn = DataConnection(
+                data_join_node_name="purchases",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_purchase.csv'))
+
+            TestOBMOnly.products_conn = DataConnection(
+                data_join_node_name="products",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_products.csv'))
+
+            TestOBMOnly.results_connection = DataConnection(
+                connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                        access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                        secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.results_cos_path)
+            )
 
         TestOBMOnly.data_connections = [self.main_conn,
                                         self.customers_conn,
@@ -199,14 +235,6 @@ class TestOBMOnly(unittest.TestCase):
                                         self.purchases_conn,
                                         self.products_conn]
 
-        TestOBMOnly.results_connection = DataConnection(
-            connection=S3Connection(endpoint_url=self.cos_endpoint,
-                                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.results_cos_path)
-        )
-
     @print_test_separators
     def test_02_create_data_join_graph__graph_created(self):
         print("Defining DataJoinGraph...")
@@ -237,13 +265,9 @@ class TestOBMOnly(unittest.TestCase):
     @print_test_separators
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
-        if is_cp4d():
-            TestOBMOnly.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                            project_id='18fabb4b-bc3d-4797-b30d-88078a9d4b8e',
-                                            space_id=self.space_id)
-        else:
-            TestOBMOnly.experiment = AutoAI(wml_credentials=self.wml_credentials,
-                                            space_id=self.space_id)
+        TestOBMOnly.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                        project_id=self.project_id,
+                                        space_id=self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -273,7 +297,7 @@ class TestOBMOnly(unittest.TestCase):
             prediction_type=AutoAI.PredictionType.REGRESSION,
             prediction_column='next_purchase',
             scoring=AutoAI.Metrics.LOG_LOSS,
-            t_shirt_size=self.experiment.TShirtSize.L,
+            t_shirt_size=self.experiment.TShirtSize.L if not is_cp4d() else self.experiment.TShirtSize.S,
             data_join_graph=self.data_join_graph,
             data_join_only=True,
         )
@@ -289,45 +313,61 @@ class TestOBMOnly(unittest.TestCase):
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
     def test_08a_check_data_join_node_names(self):
-        main_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_main.csv'))
+        if self.wml_client.ICP:
+            main_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_main.csv'))
 
-        customers_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_customers.csv'))
+            customers_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_customers.csv'))
 
-        transactions_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_transactions.csv'))
+            transactions_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_transactions.csv'))
 
-        purchases_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_purchase.csv'))
+            purchases_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_purchase.csv'))
 
-        products_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_products.csv'))
+            products_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_products.csv'))
+        else:
+            main_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_main.csv'))
+
+            customers_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_customers.csv'))
+
+            transactions_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_transactions.csv'))
+
+            purchases_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_purchase.csv'))
+
+            products_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_products.csv'))
 
         data_connections = [main_conn,
                             customers_conn,
@@ -381,6 +421,9 @@ class TestOBMOnly(unittest.TestCase):
 
     @print_test_separators
     def test_11_visualize_obm_pipeline(self):
+        if self.wml_client.ICP or self.wml_client.WSD:
+            self.skipTest("Visualizing pipeline not supported on CPD")
+
         print("Visualizing OBM model ...")
         TestOBMOnly.data_join_pipeline = self.remote_auto_pipelines.get_preprocessing_pipeline()
         assert isinstance(self.data_join_pipeline._pipeline_json, list)
@@ -389,6 +432,8 @@ class TestOBMOnly(unittest.TestCase):
 
     @print_test_separators
     def test_12_check_if_data_join_pipeline_graph_correct(self):
+        if self.wml_client.ICP or self.wml_client.WSD:
+            self.skipTest("Visualizing pipeline not supported on CPD")
         pipeline_json = self.data_join_pipeline._pipeline_json
         graph = self.data_join_pipeline._graph_json
 
@@ -452,8 +497,7 @@ class TestOBMOnly(unittest.TestCase):
     @print_test_separators
     def test_16_get_historical_optimizer_with_data_join_graph(self):
         print("Fetching historical optimizer with OBM only...")
-        run_id = self.experiment.runs(filter=self.OPTIMIZER_NAME).list()[['run_id']].values[-1][0]
-        TestOBMOnly.historical_opt = self.experiment.runs.get_optimizer(run_id=run_id)
+        TestOBMOnly.historical_opt = self.experiment.runs.get_optimizer(run_id=self.run_id)
         self.assertIsInstance(self.historical_opt.get_params()['data_join_graph'], DataJoinGraph,
                               msg="data_join_graph was incorrectly loaded")
 
