@@ -12,18 +12,17 @@ from ibm_watson_machine_learning.deployment import Batch
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, DSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
-from ibm_watson_machine_learning.tests.utils import (
-    get_wml_credentials, get_cos_credentials, is_cp4d, get_env, print_test_separators)
+from ibm_watson_machine_learning.tests.utils import print_test_separators
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
     bucket_name_gen, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
 
 
 
@@ -38,7 +37,8 @@ get_join_extractors = OBMPipelineGraphBuilder.get_join_extractors
 get_extractor_columns = OBMPipelineGraphBuilder.get_extractor_columns
 get_extractor_transformations = OBMPipelineGraphBuilder.get_extractor_transformations
 
-
+@unittest.skip('not yet supported')
+@unittest.skipIf(is_cp4d(), "Excel files and delimiters not yet supported on CPD")
 class TestOBMAndKB(unittest.TestCase):
     data_join_graph: 'DataJoinGraph' = None
     wml_client: 'APIClient' = None
@@ -72,6 +72,7 @@ class TestOBMAndKB(unittest.TestCase):
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
+    cos_resource_instance_id = None
     data_cos_path = 'data/'
 
     results_cos_path = 'results_wml_autoai'
@@ -109,10 +110,11 @@ class TestOBMAndKB(unittest.TestCase):
     #     space_id = '4e0541b8-174b-4d04-ae21-14c15475d68a'
 
     project_id = None
+    space_id = None
     asset_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -135,7 +137,11 @@ class TestOBMAndKB(unittest.TestCase):
                       days_old=2)
         TestOBMAndKB.space_id = get_space_id(self.wml_client, self.space_name,
                                     cos_resource_instance_id=self.cos_resource_instance_id)
-        TestOBMAndKB.project_id = None
+
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -169,68 +175,107 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_01_create_multiple_data_connections__connections_created(self):
         print("Creating multiple data connections...")
-        TestOBMAndKB.main_conn = DataConnection(
-            data_join_node_name="main",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_main_semicolon_delimiter.csv'))
+        if self.wml_client.ICP:
+            TestOBMAndKB.main_conn = DataConnection(
+                data_join_node_name="main",
+                location=FSLocation(path=self.data_location + 'group_customer_main_semicolon_delimiter.csv'))
 
-        main_conn_without_delimiter = DataConnection(
-            data_join_node_name="main",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_main.csv'))
+            main_conn_without_delimiter = DataConnection(
+                data_join_node_name="main",
+                location=FSLocation(path=self.data_location + 'group_customer_main.csv'))
 
-        TestOBMAndKB.customers_transactions_conn = DataConnection(
-            data_join_node_name=["customers", "transactions"],
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer.xlsx'))
+            TestOBMAndKB.customers_transactions_conn = DataConnection(
+                data_join_node_name=["customers", "transactions"],
+                location=FSLocation(path=self.data_location + 'group_customer.xlsx'))
 
-        TestOBMAndKB.customers_conn = DataConnection(
-            data_join_node_name="customers",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_customers.csv'))
+            TestOBMAndKB.customers_conn = DataConnection(
+                data_join_node_name="customers",
+                location=FSLocation(path=self.data_location + 'group_customer_customers.csv'))
 
-        TestOBMAndKB.transactions_conn = DataConnection(
-            data_join_node_name="transactions",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_transactions.csv'))
+            TestOBMAndKB.transactions_conn = DataConnection(
+                data_join_node_name="transactions",
+                location=FSLocation(path=self.data_location + 'group_customer_transactions.csv'))
 
-        TestOBMAndKB.purchases_conn = DataConnection(
-            data_join_node_name="purchases",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_purchase.csv'))
+            TestOBMAndKB.purchases_conn = DataConnection(
+                data_join_node_name="purchases",
+                location=FSLocation(path=self.data_location + 'group_customer_purchase.csv'))
 
-        TestOBMAndKB.products_conn = DataConnection(
-            data_join_node_name="products",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_products.csv'))
+            TestOBMAndKB.products_conn = DataConnection(
+                data_join_node_name="products",
+                location=FSLocation(path=self.data_location + 'group_customer_products.csv'))
+
+            TestOBMAndKB.results_connection = None
+        else:
+            TestOBMAndKB.main_conn = DataConnection(
+                data_join_node_name="main",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_main_semicolon_delimiter.csv'))
+
+            main_conn_without_delimiter = DataConnection(
+                data_join_node_name="main",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_main.csv'))
+
+            TestOBMAndKB.customers_transactions_conn = DataConnection(
+                data_join_node_name=["customers", "transactions"],
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer.xlsx'))
+
+            TestOBMAndKB.customers_conn = DataConnection(
+                data_join_node_name="customers",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_customers.csv'))
+
+            TestOBMAndKB.transactions_conn = DataConnection(
+                data_join_node_name="transactions",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_transactions.csv'))
+
+            TestOBMAndKB.purchases_conn = DataConnection(
+                data_join_node_name="purchases",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_purchase.csv'))
+
+            TestOBMAndKB.products_conn = DataConnection(
+                data_join_node_name="products",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_products.csv'))
+
+            TestOBMAndKB.results_connection = DataConnection(
+                connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                        access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                        secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.results_cos_path)
+            )
 
         TestOBMAndKB.data_connections = [self.main_conn,
                                          self.customers_transactions_conn,
@@ -238,18 +283,10 @@ class TestOBMAndKB(unittest.TestCase):
                                          self.products_conn]
 
         TestOBMAndKB.batch_deployment_data_connections = [main_conn_without_delimiter,
-                                         self.customers_conn,
-                                         self.transactions_conn,
-                                         self.purchases_conn,
-                                         self.products_conn]
-
-        TestOBMAndKB.results_connection = DataConnection(
-            connection=S3Connection(endpoint_url=self.cos_endpoint,
-                                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.results_cos_path)
-        )
+                                                          self.customers_conn,
+                                                          self.transactions_conn,
+                                                          self.purchases_conn,
+                                                          self.products_conn]
 
     @print_test_separators
     def test_02_create_data_join_graph__graph_created(self):
@@ -281,12 +318,9 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
-        if is_cp4d():
-            TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                             project_id=self.project_id)
-        else:
-            TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials,
-                                             space_id=self.space_id)
+        TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                         project_id=self.project_id,
+                                         space_id=self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -317,7 +351,7 @@ class TestOBMAndKB(unittest.TestCase):
             max_number_of_estimators=1,
             daub_include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM],
             data_join_graph=self.data_join_graph,
-            t_shirt_size=self.experiment.TShirtSize.L,
+            t_shirt_size=self.experiment.TShirtSize.L if not is_cp4d() else self.experiment.TShirtSize.S,
             test_size=0.1
         )
 
@@ -332,45 +366,61 @@ class TestOBMAndKB(unittest.TestCase):
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
     def test_08a_check_data_join_node_names(self):
-        main_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_main_semicolon_delimiter.csv'))
+        if self.wml_client.ICP:
+            main_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_main_semicolon_delimiter.csv'))
 
-        customers_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_customers.csv'))
+            customers_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_customers.csv'))
 
-        transactions_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_transactions.csv'))
+            transactions_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_transactions.csv'))
 
-        purchases_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_purchase.csv'))
+            purchases_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_purchase.csv'))
 
-        products_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'group_customer_products.csv'))
+            products_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'group_customer_products.csv'))
+        else:
+            main_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_main_semicolon_delimiter.csv'))
+
+            customers_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_customers.csv'))
+
+            transactions_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_transactions.csv'))
+
+            purchases_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_purchase.csv'))
+
+            products_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'group_customer_products.csv'))
 
         data_connections = [main_conn,
                             customers_conn,
@@ -661,28 +711,24 @@ class TestOBMAndKB(unittest.TestCase):
     def test_26_batch_deployment_setup_and_preparation(self):
         if is_cp4d():
             TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
-            self.wml_client.set.default_space(self.space_id)
-
         else:
             TestOBMAndKB.service = Batch(self.wml_credentials,
                                          source_space_id=self.space_id,
                                          target_wml_credentials=self.wml_credentials,
                                          target_space_id=self.space_id)
 
-        # self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
-        #
-        # delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
-        #
-        # self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_27_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
             # experiment_run_id='ead25ed8-0218-4d13-b6ad-c6218f910154',
-            model=self.pipeline,
+            model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME)
 
+        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+
     @print_test_separators
     def test_28_score_deployed_model(self):
         scoring_params = self.service.run_job(
@@ -709,6 +755,9 @@ class TestOBMAndKB(unittest.TestCase):
     def test_30_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
     #################################
     #      NOTEBOOK SECTION       #
@@ -773,19 +822,14 @@ class TestOBMAndKB(unittest.TestCase):
     def test_35_batch_deployment_setup_and_preparation_notebook(self):
         if is_cp4d():
             TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
-            self.wml_client.set.default_space(self.space_id)
-
         else:
             TestOBMAndKB.service = Batch(self.wml_credentials,
+                                         source_space_id=self.space_id,
                                          source_project_id=self.project_id,
                                          target_wml_credentials=self.wml_credentials,
                                          target_space_id=self.space_id)
 
-        # self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
-        #
-        # delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
-        #
-        # self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_36__deploy__deploy_best_computed_pipeline_from_autoai_on_wml_notebook(self):
@@ -794,6 +838,8 @@ class TestOBMAndKB(unittest.TestCase):
             model=self.pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
+        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+
     @print_test_separators
     def test_37a_score_deployed_model_notebook(self):
         scoring_params = self.service.run_job(
@@ -837,6 +883,9 @@ class TestOBMAndKB(unittest.TestCase):
     def test_39_delete_deployment_notebook(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 
 if __name__ == '__main__':
