@@ -12,12 +12,11 @@ from ibm_watson_machine_learning.deployment import Batch
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, DSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
-from ibm_watson_machine_learning.tests.utils import (
-    get_wml_credentials, get_cos_credentials, is_cp4d, get_env, print_test_separators)
+from ibm_watson_machine_learning.tests.utils import print_test_separators
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
@@ -39,6 +38,7 @@ get_extractor_columns = OBMPipelineGraphBuilder.get_extractor_columns
 get_extractor_transformations = OBMPipelineGraphBuilder.get_extractor_transformations
 
 
+@unittest.skipIf(is_cp4d, "Excel files and delimiters not yet supported on CPD")
 class TestOBMAndKB(unittest.TestCase):
     data_join_graph: 'DataJoinGraph' = None
     wml_client: 'APIClient' = None
@@ -70,8 +70,10 @@ class TestOBMAndKB(unittest.TestCase):
     holdout_data = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
+    pod_version = environ.get('KB_VERSION', None)
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
+    cos_resource_instance_id = None
     data_cos_path = 'data/'
 
     results_cos_path = 'results_wml_autoai'
@@ -109,9 +111,10 @@ class TestOBMAndKB(unittest.TestCase):
     #     space_id = '4e0541b8-174b-4d04-ae21-14c15475d68a'
 
     asset_id = None
+    space_id = None
 
     @classmethod
-    def setUp(cls) -> None:
+    def setUpClass(cls) -> None:
         """
         Load WML credentials from config.ini file based on ENV variable.
         """
@@ -122,6 +125,7 @@ class TestOBMAndKB(unittest.TestCase):
             cls.cos_resource_instance_id = cls.cos_credentials.get('resource_instance_id')
 
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
+        cls.project_id = cls.wml_credentials.get('project_id')
 
     @print_test_separators
     def test_00a_space_cleanup(self):
@@ -131,7 +135,11 @@ class TestOBMAndKB(unittest.TestCase):
                       days_old=2)
         TestOBMAndKB.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        TestOBMAndKB.project_id = None
+
+        if self.wml_client.ICP:
+            self.wml_client.set.default_project(self.project_id)
+        else:
+            self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -165,55 +173,74 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_01_create_multiple_data_connections__connections_created(self):
         print("Creating multiple data connections...")
-        TestOBMAndKB.main_conn = DataConnection(
-            data_join_node_name="main",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_1.csv'))
+        if self.wml_client.ICP:
+            TestOBMAndKB.main_conn = DataConnection(
+                data_join_node_name="main",
+                location=FSLocation(path=self.data_location + 'temp_1.csv'))
 
-        TestOBMAndKB.temp_2_conn = DataConnection(
-            data_join_node_name="temp_2",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_2.csv'))
+            TestOBMAndKB.temp_2_conn = DataConnection(
+                data_join_node_name="temp_2",
+                location=FSLocation(path=self.data_location + 'temp_2.csv'))
 
-        TestOBMAndKB.temp_3_conn = DataConnection(
-            data_join_node_name="temp_3",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_3.csv'))
+            TestOBMAndKB.temp_3_conn = DataConnection(
+                data_join_node_name="temp_3",
+                location=FSLocation(path=self.data_location + 'temp_3.csv'))
 
-        TestOBMAndKB.temp_4_conn = DataConnection(
-            data_join_node_name="temp_4",
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_4.csv'))
+            TestOBMAndKB.temp_4_conn = DataConnection(
+                data_join_node_name="temp_4",
+                location=FSLocation(path=self.data_location + 'temp_4.csv'))
+
+            TestOBMAndKB.results_connection = None
+        else:
+            TestOBMAndKB.main_conn = DataConnection(
+                data_join_node_name="main",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_1.csv'))
+
+            TestOBMAndKB.temp_2_conn = DataConnection(
+                data_join_node_name="temp_2",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_2.csv'))
+
+            TestOBMAndKB.temp_3_conn = DataConnection(
+                data_join_node_name="temp_3",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_3.csv'))
+
+            TestOBMAndKB.temp_4_conn = DataConnection(
+                data_join_node_name="temp_4",
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_4.csv'))
+
+            TestOBMAndKB.results_connection = DataConnection(
+                connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                        access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                        secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.results_cos_path)
+            )
 
         TestOBMAndKB.data_connections = [self.main_conn,
                                          self.temp_2_conn,
                                          self.temp_3_conn,
                                          self.temp_4_conn]
 
-        TestOBMAndKB.results_connection = DataConnection(
-            connection=S3Connection(endpoint_url=self.cos_endpoint,
-                                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.results_cos_path)
-        )
-
     @print_test_separators
     def test_02_create_data_join_graph__graph_created(self):
         print("Defining DataJoinGraph...")
@@ -241,12 +268,9 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
-        if is_cp4d():
-            TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                             project_id=self.project_id)
-        else:
-            TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials,
-                                             space_id=self.space_id)
+        TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                         project_id=self.project_id,
+                                         space_id=self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -277,7 +301,8 @@ class TestOBMAndKB(unittest.TestCase):
             max_number_of_estimators=1,
             data_join_graph=self.data_join_graph,
             t_shirt_size=self.experiment.TShirtSize.L,
-            test_size=0.1
+            test_size=0.1,
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -291,37 +316,50 @@ class TestOBMAndKB(unittest.TestCase):
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
     def test_08a_check_data_join_node_names(self):
-        main_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_1.csv'))
+        if self.wml_client.ICP:
+            main_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'temp_1.csv'))
 
-        temp_2_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_2.csv'))
+            temp_2_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'temp_2.csv'))
 
-        temp_3_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_3.csv'))
+            temp_3_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'temp_3.csv'))
 
-        temp_4_conn = DataConnection(
-            connection=S3Connection(
-                endpoint_url=self.cos_endpoint,
-                access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-            location=S3Location(bucket=self.bucket_name,
-                                path=self.data_cos_path + 'temp_4.csv'))
+            temp_4_conn = DataConnection(
+                location=FSLocation(path=self.data_location + 'temp_4.csv'))
+        else:
+            main_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_1.csv'))
+
+            temp_2_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_2.csv'))
+
+            temp_3_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_3.csv'))
+
+            temp_4_conn = DataConnection(
+                connection=S3Connection(
+                    endpoint_url=self.cos_endpoint,
+                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                location=S3Location(bucket=self.bucket_name,
+                                    path=self.data_cos_path + 'temp_4.csv'))
 
 
         data_connections = [main_conn,
@@ -611,28 +649,23 @@ class TestOBMAndKB(unittest.TestCase):
     def test_26_batch_deployment_setup_and_preparation(self):
         if is_cp4d():
             TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
-            self.wml_client.set.default_space(self.space_id)
-
         else:
             TestOBMAndKB.service = Batch(self.wml_credentials,
                                          source_space_id=self.space_id,
                                          target_wml_credentials=self.wml_credentials,
                                          target_space_id=self.space_id)
 
-        # self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
-        #
-        # delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
-        #
-        # self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_27_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
         self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            # experiment_run_id='ead25ed8-0218-4d13-b6ad-c6218f910154',
-            model=self.pipeline,
+            model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME)
 
+        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+
     @print_test_separators
     def test_28_score_deployed_model(self):
         scoring_params = self.service.run_job(
@@ -659,6 +692,9 @@ class TestOBMAndKB(unittest.TestCase):
     def test_30_delete_deployment(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
     #################################
     #      NOTEBOOK SECTION       #
@@ -723,19 +759,14 @@ class TestOBMAndKB(unittest.TestCase):
     def test_35_batch_deployment_setup_and_preparation_notebook(self):
         if is_cp4d():
             TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
-            self.wml_client.set.default_space(self.space_id)
-
         else:
             TestOBMAndKB.service = Batch(self.wml_credentials,
+                                         source_space_id=self.space_id,
                                          source_project_id=self.project_id,
                                          target_wml_credentials=self.wml_credentials,
                                          target_space_id=self.space_id)
 
-        # self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
-        #
-        # delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
-        #
-        # self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_36__deploy__deploy_best_computed_pipeline_from_autoai_on_wml_notebook(self):
@@ -744,6 +775,8 @@ class TestOBMAndKB(unittest.TestCase):
             model=self.pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
+        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
+
     @print_test_separators
     def test_37a_score_deployed_model_notebook(self):
         scoring_params = self.service.run_job(
@@ -787,6 +820,9 @@ class TestOBMAndKB(unittest.TestCase):
     def test_39_delete_deployment_notebook(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if is_cp4d() else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 
 if __name__ == '__main__':
