@@ -364,7 +364,7 @@ class Training(WMLResource):
                 elif self._client.default_project_id is not None:
                     training_configuration_metadata['project_id'] = self._client.default_project_id
 
-            if self._client.ICP_30:
+            if self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                 if self.ConfigurationMetaNames.FEDERATED_LEARNING in meta_props:
                     training_configuration_metadata['federated_learning'] = \
                         meta_props[self.ConfigurationMetaNames.FEDERATED_LEARNING]
