@@ -43,9 +43,12 @@ __all__ = [
     'TrainingDataSourceIsNotFile',
     'VisualizationFailed',
     'InvalidPredictionType',
-    'DataLocationTypeNotSupported',
     'InvalidIdType',
-    'NoneDataConnection'
+    'NoneDataConnection',
+    'CannotReadSavedRemoteDataBeforeFit',
+    'NotWSDEnvironment',
+    'NotExistingCOSResource',
+    'AdditionalParameterIsUnexpected'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -211,11 +214,6 @@ class InvalidPredictionType(WMLClientError, ValueError):
         WMLClientError.__init__(self, f"Cannot recognize prediction type: {value_name}", reason)
 
 
-class DataLocationTypeNotSupported(WMLClientError, ValueError):
-    def __init__(self, value_name=None, reason=None):
-        WMLClientError.__init__(self, f"Data Location type: {value_name} is not supported for this action", reason)
-
-
 class InvalidIdType(WMLClientError, ValueError):
     def __init__(self, typ):
         WMLClientError.__init__(self, f"Unexpected type of id: {typ}")
@@ -223,4 +221,24 @@ class InvalidIdType(WMLClientError, ValueError):
 
 class NoneDataConnection(WMLClientError, ValueError):
     def __init__(self, resource_name):
-        WMLClientError.__init__(self, f"Invalid DataConnection in {resource_name} list. DataConnection cannot be None")
\ No newline at end of file
+        WMLClientError.__init__(self, f"Invalid DataConnection in {resource_name} list. DataConnection cannot be None")
+
+
+class CannotReadSavedRemoteDataBeforeFit(WMLClientError, ValueError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Cannot read saved remote data before fit on ICP environment")
+
+
+class NotWSDEnvironment(WMLClientError, ValueError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Function cannot be used outside WSD environment.")
+
+
+class NotExistingCOSResource(WMLClientError, ValueError):
+    def __init__(self, bucket, path):
+        WMLClientError.__init__(self, f"There is no COS resource: {path} in bucket: {bucket}.")
+
+
+class AdditionalParameterIsUnexpected(WMLClientError):
+    def __init__(self, param):
+        WMLClientError.__init__(self, f"Additional parameter is not expected: {param}")
\ No newline at end of file
