@@ -20,7 +20,7 @@ __all__ = [
     'prepare_auto_ai_model_to_publish_notebook_normal_scenario',
     'prepare_auto_ai_model_to_publish',
     'remove_file',
-    'RunDetailsGenerator',
+    'ProgressGenerator',
     'is_ipython',
     'try_import_lale',
     'try_load_dataset',
@@ -40,7 +40,8 @@ __all__ = [
     'init_cos_client',
     'check_graphviz_binaries',
     'try_import_joblib',
-    'get_sw_spec_and_type_based_on_sklearn'
+    'get_sw_spec_and_type_based_on_sklearn',
+    'validate_additional_params_for_optimizer'
 ]
 
 import io
@@ -62,7 +63,7 @@ from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from .enums import RunStateTypes
 from .errors import (MissingPipeline, AutoAIComputeError, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
-                     VisualizationFailed)
+                     VisualizationFailed, AdditionalParameterIsUnexpected)
 
 if TYPE_CHECKING:
     from io import BytesIO, BufferedIOBase
@@ -378,6 +379,7 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
         pipeline_model: Union['Pipeline', 'TrainablePipeline'],
         result_connection,
         cos_client,
+        run_params: Dict,
         space_id: str) -> Union[Tuple[str, Dict[str, dict]]]:
     """
     Prepares autoai model to publish in Watson Studio via COS.
@@ -394,6 +396,9 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
     cos_client: ibm_boto3.resource, required
         initialized COS client
 
+    run_params: dictionary, required
+        Dictionary with training details
+
     space_id: str, required
 
     Returns
@@ -407,12 +412,18 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
 
     bucket = result_connection.location.bucket
     cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
-
     with open('request.json', 'r') as f:
         request_str = f.read()
 
+    # note: only if there was 1 estimator during training
+    if 'content_location' not in request_str:
+        request_path = f"{path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+        cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
+        with open('request.json', 'r') as f:
+            request_str = f.read()
+
     request_json: Dict[str, dict] = json.loads(request_str)
-    request_json['content_location']['connection'] = result_connection.connection.to_dict()
+    request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
     request_json = preprocess_request_json(request_json, space_id)
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
@@ -546,6 +557,10 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
 
     if wml_client.ICP:
         request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
+        # note: only if there was 1 estimator during training
+        if 'content_location' not in request_str:
+            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+            request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
 
     else:
         cos_client = init_cos_client(run_params['entity']['results_reference']['connection'])
@@ -554,6 +569,13 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
         with open('request.json', 'r') as f:
             request_str = f.read()
 
+        # note: only if there was 1 estimator during training
+        if 'content_location' not in request_str:
+            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+            cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
+            with open('request.json', 'r') as f:
+                request_str = f.read()
+
     request_json: Dict[str, dict] = json.loads(request_str)
     # note: fill connection details
     request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
@@ -726,77 +748,43 @@ def remove_file(filename: str):
         os.remove(filename)
 
 
-class RunDetailsGenerator:
-    """
-    Generator class to produce specified run details. Needed for progress bar.
+class ProgressGenerator:
+    def __init__(self, number_of_estimators):
+        self.progress_messages = {
+            ":::Pipeline node automl started": 1,
+            ":::Node automl: Scheduling job": 1,
+            ":::Node automl: Starting AutoAI on WML": 1,
+            "pre_hpo_d_output:::Node automl: AutoAI model computed": number_of_estimators,
+            "hpo_d_running_input:before_pipeline_execution::Node automl: AutoAI model computed": 40*number_of_estimators,
+            "hpo_c_running_input:before_pipeline_execution::Node automl: AutoAI model computed": 100*number_of_estimators,
+            ":::Node automl: Started daub_running stage": 1,
+            ":::Node automl: Started hpo_d stage": 1,
+            "hpo_d_output:::Node automl: AutoAI model computed": 1,
+            "cognito_output:::Node automl: AutoAI model computed": 1,
+            ":::Node automl: Completed feature_importance_pipeline stage": 1,
+            ":::Node automl: Found best data transformation chain and done HPO": 1,
+            "hpo_c_output:::Node automl: AutoAI model computed": 1,
+            ":::Node automl: Completed training of Full_dataset": 1,
+            ":::Node automl: Finished pipeline composition": 1,
+            ":::Pipeline node automl terminated": 1,
+            ":::Training job": 1
+        }
+        self.total = sum(self.progress_messages.values())
+        self.progress_bar_size_factor = 1
+        self.position = 0
 
-    Parameters
-    ----------
-    wml_client: APIClient, required
-        WML Client Instance
+    def get_progress(self, text):
+        if self.position + 1 >= self.total:
+            return 0
 
-    run_id: str, required
-        ID of the run/fit.
+        for i, e in enumerate(self.progress_messages):
+            if e in text:
+                self.position += 1
+                return self.progress_bar_size_factor
+        return 0
 
-    wait_time: float, required
-        Waiting time in seconds, how long we will wait until next details will be fetched.
-    """
-
-    def __init__(self, wml_client: 'APIClient', run_id: str, wait_time: float) -> None:
-        self._wml_client = wml_client
-        self.run_id = run_id
-        self.wait_time = wait_time
-        self.finished = False
-        status = self._wml_client.training.get_status(training_uid=self.run_id)
-        self.message = status.get('message', {}).get('text', 'Started waiting for resources.').split(': ')[-1]
-
-    def __iter__(self):
-        return self
-
-    def __next__(self):
-        sleep(self.wait_time)
-        try:
-            status = self._wml_client.training.get_status(training_uid=self.run_id)
-            state = status.get('state')
-            message = status.get('message', {}).get('text', 'Started waiting for resources.').split(': ')[-1]
-
-        except ApiRequestFailure as e:
-            state = {'state': 'ApiRequestFailure'}
-            message = f'{e}, reconnecting...'
-
-        if state == RunStateTypes.FAILED:
-            sleep(3)
-            try:
-                status = self._wml_client.training.get_status(training_uid=self.run_id)
-                message = status.get('failure', {}).get('errors', [])
-            except ApiRequestFailure as e:
-                message = f'{e}, reconnecting...'
-
-            if 'Not Found' in str(message) or 'HeadObject' in str(message):
-                raise AutoAIComputeError(self.run_id,
-                                         reason=f"Fetching training data error. Please check if COS credentials, "
-                                                f"bucket name and path are correct or file system path is correct.")
-
-            elif 'Failed_Image' in str(message):
-                raise AutoAIComputeError(
-                    self.run_id,
-                    reason=f"This version of WML V4 SDK with AutoAI component is no longer supported. "
-                           f"Please update your package to the newest version. "
-                           f"Error: {message}")
-
-            else:
-                raise AutoAIComputeError(self.run_id, reason=f"Error: {message}")
-
-        # note: additional checks, OBM produces similar completed message state, we need to finish only when KB finished
-        elif state == RunStateTypes.COMPLETED and 'Training job' in message and 'completed' in message:
-            if self.finished:
-                raise StopIteration
-            else:
-                self.finished = True
-                return message
-
-        else:
-            return message
+    def get_total(self):
+        return self.progress_bar_size_factor * self.total
 
 
 def is_ipython():
@@ -816,7 +804,7 @@ def try_import_lale():
     """
     Check if lale package is installed in local environment, if not, just download and install it.
     """
-    lale_version = '0.4.1'
+    lale_version = '0.4.4'
     try:
         import lale
         from packaging import version
@@ -936,29 +924,6 @@ def try_import_joblib():
     compatibility issues.
     """
 
-    def fallback_load(f):
-        @wraps(f)
-        def _f(self, *method_args, **method_kwargs):
-            try:
-                output = f(*method_args, **method_kwargs)
-
-            except:
-                import sklearn
-                if '0.20' in str(sklearn.__version__):
-                    raise LibraryNotCompatible(
-                        reason=f"Installed scikit-learn version: {sklearn.__version__} is not compatible with "
-                               f"version included in AutoAI pipeline. Please try to install another 0.23.2 version.")
-                else:
-                    raise LibraryNotCompatible(
-                        reason=f"Installed scikit-learn version: {sklearn.__version__} is not compatible with "
-                               f"version included in AutoAI pipeline. Please try to install another 0.20.3 version.")
-
-            return output
-
-        return _f
-
-    from types import MethodType
-
     try:
         # note only up to scikit version 0.20.3
         from sklearn.externals import joblib
@@ -967,9 +932,6 @@ def try_import_joblib():
         # only for scikit 0.23.*
         import joblib
 
-    new_load = fallback_load(joblib.load)
-    joblib.load = MethodType(new_load, joblib)
-
     return joblib
 
 
@@ -1017,7 +979,7 @@ def try_load_dataset(
 
 
 def check_dependencies_versions(lib_name: str = None, error: bool = False, msg: str = '') -> None:
-    """Check scikit, xgboost and lightbm installed versions and inform the user about needed ones.
+    """Check xgboost and lightbm installed versions and inform the user about needed ones.
 
     Parameters
     ----------
@@ -1031,26 +993,16 @@ def check_dependencies_versions(lib_name: str = None, error: bool = False, msg:
         Error message.
     """
 
-    scikit_version = '0.23.2'
-    numpy_version = '1.19.1'
     xgboost_version = '0.90'
     lightgbm_version = '2.2.3'
 
-    scikit_message = f'To use AutoAI, you need to have scikit-learn {scikit_version} installed.'
-    numpy_message = f'To use AutoAI, you need to have numpy {numpy_version} installed.'
     xgboost_message = f'To use AutoAI with xgboost estimators, you need to have xgboost {xgboost_version} installed.'
     lightgbm_message = f'To use AutoAI with lightgbm estimators, you need to have lightgbm {lightgbm_version} installed.'
 
     def print_or_warn(library: str) -> None:
-        if library == 'scikit':
-            message = scikit_message
-
-        elif library == 'xgboost':
+        if library == 'xgboost':
             message = xgboost_message
 
-        elif library == 'numpy':
-            message = numpy_message
-
         else:
             message = lightgbm_message
 
@@ -1063,17 +1015,6 @@ def check_dependencies_versions(lib_name: str = None, error: bool = False, msg:
         else:
             warn(message=message)
 
-    # note: scikit version check
-    try:
-        if lib_name == 'scikit' or lib_name is None:
-            import sklearn
-            if sklearn.__version__ != scikit_version:
-                print_or_warn(library='scikit')
-
-    except (ImportError, AttributeError, ModuleNotFoundError):
-        print_or_warn(library='scikit')
-    # --- end note
-
     # note: xgboost version check
     try:
         if lib_name == 'xgboost' or lib_name is None:
@@ -1096,18 +1037,6 @@ def check_dependencies_versions(lib_name: str = None, error: bool = False, msg:
         print_or_warn(library='lightgbm')
     # --- end note
 
-    # note: numpy version check
-    try:
-        if lib_name == 'numpy' or lib_name is None:
-            import numpy
-            from packaging import version
-            if version.parse(numpy.__version__) < version.parse(numpy_version):
-                print_or_warn(library='numpy')
-
-    except (ImportError, AttributeError, ModuleNotFoundError):
-        print_or_warn(library='numpy')
-    # --- end note
-
 
 def prepare_cos_client(
         training_data_references: List['DataConnection'] = None,
@@ -1335,23 +1264,67 @@ def check_graphviz_binaries(f):
     return _f
 
 
-def get_sw_spec_and_type_based_on_sklearn(client: 'APIClient') -> Tuple[str, str]:
-    """Based on user environment, check sklearn version and find apropriate sw spec.
+def get_sw_spec_and_type_based_on_sklearn(client: 'APIClient', spec: str) -> Tuple[str, str]:
+    """Based on user environment and pipeline sw spec, check sklearn version and find apropriate sw spec.
 
     Returns
     -------
     model_type, sw_spec
     """
     import sklearn
-    if '0.20.' in sklearn.__version__:
+
+    if '0.20.' in sklearn.__version__ and 'autoai-kb_3.0-py3.6' == spec:
         sw_spec = client.software_specifications.get_id_by_name('autoai-kb_3.0-py3.6')
         model_type = 'scikit-learn_0.20'
 
-    elif '0.23.' in sklearn.__version__:
-        sw_spec = client.software_specifications.get_id_by_name('autoai-kb_3.1-py3.6')
+    elif '0.20.' in sklearn.__version__ and 'autoai-kb_3.0-py3.6' != spec:
+        raise LibraryNotCompatible(reason="Your version of scikit-learn is different then trained pipeline. "
+                                          "Trained pipeline version: 0.23.* "
+                                          "Your version: " + sklearn.__version__)
+
+    elif '0.23.' in sklearn.__version__ and 'autoai-kb_3.1-py3.7' == spec:
+        sw_spec = client.software_specifications.get_id_by_name('autoai-kb_3.1-py3.7')
         model_type = 'scikit-learn_0.23'
 
+    elif '0.23.' in sklearn.__version__ and 'autoai-kb_3.1-py3.7' != spec:
+        raise LibraryNotCompatible(reason="Your version of scikit-learn is different then trained pipeline. "
+                                          "Trained pipeline version: 0.20.* "
+                                          "Your version: " + sklearn.__version__)
+
     else:
         raise LibraryNotCompatible(reason="Your version of scikit-learn is not supported. Use one of [0.20.*, 0.23.*]")
 
     return model_type, sw_spec
+
+
+def validate_additional_params_for_optimizer(params):
+    expected_params = [
+        'learning_type', 'positive_label', 'scorer_for_ranking', 'scorers', 'num_folds', 'random_state',
+        'preprocessor_flag', 'preprocessor_hpo_flag', 'preprocessor_hpo_estimator', 'hpo_searcher', 'cv_num_folds',
+        'hpo_d_iter_threshold', 'hpo_c_iter_threshold', 'max_initial_points', 'preprocess_transformer_chain',
+        'daub_ensembles_flag', 'max_num_daub_ensembles', 'run_hpo_after_daub_flag', 'daub_include_only_estimators',
+        'run_cognito_flag', 'cognito_ensembles_flag', 'max_num_cognito_ensembles', 'cognito_display_flag',
+        'run_hpo_after_cognito_flag', 'cognito_kwargs', 'cognito_scorers', 'daub_adaptive_subsampling_max_mem_usage',
+        'daub_adaptive_subsampling_used_mem_ratio_threshold', 'daub_kwargs', 'compute_feature_importances_flag',
+        'compute_feature_importances_options', 'compute_feature_importances_pipeline_options', 'show_status_flag',
+        'status_msg_handler', 'state_max_report_priority', 'msg_max_report_priority', 'cognito_pass_ptype',
+        'hpo_timeout_in_seconds', 'cognito_use_feature_importances_flag', 'cognito_max_iterations',
+        'cognito_max_search_level', 'cognito_transform_names', 'cognito_use_grasspile', 'cognito_subsample',
+        'holdout_param', 'missing_values_reference_list', 'datetime_processing_flag',
+        'datetime_delete_source_columns', 'datetime_processing_options', 'ensemble_pipelines_flag', 'ensemble_tags',
+        'ensemble_comb_method', 'ensemble_selection_flag', 'ensemble_weighted_flag', 'ensemble_corr_sel_method',
+        'ensemble_corr_termination_diff_threshold', 'ensemble_num_best_pipelines', 'ensemble_num_folds',
+        'compute_pipeline_notebooks_flag', 'pipeline_ranking_metric', 'cpus_available', 'wml_status_msg_version',
+        'float32_processing_flag', 'train_remove_missing_target_rows_flag', 'train_sample_rows_test_size',
+        'train_sample_columns_index_list', 'preprocessor_cat_imp_strategy', 'preprocessor_cat_enc_encoding',
+        'preprocessor_num_imp_strategy', 'preprocessor_num_scaler_use_scaler_flag', 'preprocessor_num_scaler_with_mean',
+        'preprocessor_num_scaler_with_std', 'preprocessor_string_compress_type', 'FE_drop_unique_columns_flag',
+        'FE_drop_constant_columns_flag', 'FE_add_frequency_columns_flag', 'FE_add_missing_indicator_columns_flag',
+        'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
+        'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
+        'enabled_feature_engineering_as_json']
+
+    for k in params:
+        if k not in expected_params:
+            raise AdditionalParameterIsUnexpected(k)
+
