@@ -1,11 +1,16 @@
-################################################################################
+# (C) Copyright IBM Corp. 2020.
 #
-# Licensed Materials - Property of IBM
-# (C) Copyright IBM Corp. 2017
-# US Government Users Restricted Rights - Use, duplication disclosure restricted
-# by GSA ADP Schedule Contract with IBM Corp.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-################################################################################
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 from __future__ import print_function
 from ibm_watson_machine_learning.wml_client_error import WMLClientError
@@ -232,7 +237,10 @@ def load_model_from_directory(framework, directory_path):
      pass
     if "scikit" in framework or "xgboost" in framework:
         try:
-            from sklearn.externals import joblib
+            try:
+                from sklearn.externals import joblib
+            except ImportError:
+                import joblib
             pkl_files = [x for x in os.listdir(directory_path) if x.endswith('.pkl')]
 
             if len(pkl_files) < 1:
@@ -289,7 +297,10 @@ def save_model_to_file(model, framework, base_path, filename):
         pass
     elif framework == SCIKIT_LEARN_FRAMEWORK:
         os.makedirs(os.path.join(base_path, base_name))
-        from sklearn.externals import joblib
+        try:
+            from sklearn.externals import joblib
+        except ImportError:
+            import joblib
         joblib.dump(model, os.path.join(base_path, base_name, base_name + ".pkl"))
     elif framework == PMML_FRAMEWORK:
         pass
