@@ -639,7 +639,7 @@ class WMLResource:
         url = base_url + u'/' + uid + "/revisions"
         if not self._ICP and not self._client.WSD:
             if self._client.CLOUD_PLATFORM_SPACES:
-                params = self._client._params()
+                params = self._client._params(skip_for_create=True)
                 response = requests.post(url, headers=self._client._get_headers(),
                                          params=params,
                                          json=input_json)
@@ -649,7 +649,7 @@ class WMLResource:
         else:
             if self._client.ICP_PLATFORM_SPACES:
                 response = requests.post(url, headers=self._client._get_headers(),
-                                         params=self._client._params(),
+                                         params=self._client._params(skip_for_create=True),
                                          json=input_json, verify=False)
             else:
                 response = requests.post(url, headers=self._client._get_headers(),
