@@ -76,9 +76,15 @@ class WorkSpace:
         if not wml_credentials.get('instance_id'):
             if self.space_id is not None:
                 self.wml_client.set.default_space(self.space_id)
-            else:
+
+            elif self.project_id is not None:
                 self.wml_client.set.default_project(self.project_id)
 
+            else:
+                raise SetIDFailed(
+                    f'project_id and space_id',
+                    reason=f'project_id and space_id cannot be None at the same time.')
+
         elif wml_credentials.get('instance_id', '').lower() == 'wml_local':
             print("Connecting to WML Server...")
             if self.space_id is None:
@@ -101,13 +107,18 @@ class WorkSpace:
                     reason="These credentials are from CP4D environment, "
                            "please specify \"project_id\"")
             else:
-                outcome = self.wml_client.set.default_project(self.project_id)
-                if outcome == 'FAILURE':
+                if self.project_id is not None:
+                    outcome = self.wml_client.set.default_project(self.project_id)
+
+                else:
                     outcome = self.wml_client.set.default_space(self.space_id)
-                    if outcome == 'FAILURE':
-                        raise SetIDFailed(
-                            'project_id',
-                            reason=f"This project_id: {self.project_id} cannot be found in current environment.")
+
+                if outcome == 'FAILURE':
+                    raise SetIDFailed(
+                        f'{"project_id" if self.project_id is not None else "space_id"}',
+                        reason=f'This {"project_id" if self.project_id is not None else "space_id"}: '
+                               f'{self.project_id if self.project_id is not None else self.space_id} '
+                               f'cannot be found in current environment.')
 
             supported_versions = ('3.0.0', '3.0.1', '3.5')
             if wml_credentials[u'version'] not in supported_versions:
